@@ -17,10 +17,11 @@
 #include "qbitmap.h"
 //#include "q3ptrdict.h"
 #include "qpainter.h"
-#include "q3polygonscanner.h"
+#include "ktlq3polygonscanner.h"
 #include "qtimer.h"
-#include "q3tl.h"
-#include <q3scrollview.h>
+// #include "q3tl.h"
+// #include <q3pointarray.h>   // needed for q3polygonscanner
+#include <ktlqt3support/ktlq3scrollview.h>
 #include <qdesktopwidget.h>
 
 
@@ -220,22 +221,6 @@ const QRect& KtlQCanvasClusterizer::operator[](int i)
 //END class KtlQCanvasClusterizer
 
 
-void KtlQCanvasItemList::sort()
-{
-	qHeapSort(*  /* ((QList<KtlQCanvasItemPtr>*)) */ this);
-}
-
-
-KtlQCanvasItemList KtlQCanvasItemList::operator+(const KtlQCanvasItemList &l) const
-{
-	KtlQCanvasItemList l2(*this);
-	for(const_iterator it = l.begin(); it != l.end(); ++it)
-		l2.append(*it);
-	return l2;
-}
-
-
-
 static int gcd(int a, int b)
 {
 	int r;
@@ -289,8 +274,9 @@ void KtlQCanvas::init( const QRect & r, int chunksze, int mxclusters )
 }
 
 KtlQCanvas::KtlQCanvas( QObject* parent, const char* name )
-	: QObject( parent, name )
+	: QObject( parent /*, name*/ )
 {
+    setObjectName( name );
 	init(0,0);
 }
 
@@ -307,8 +293,10 @@ KtlQCanvas::KtlQCanvas( QPixmap p, int h, int v, int tilewidth, int tileheight )
 
 void qt_unview( KtlQCanvas * c )
 {
-	for (KtlQCanvasView* view=c->m_viewList.first(); view != 0; view=c->m_viewList.next())
+	for (QList<KtlQCanvasView*>::iterator itView =c->m_viewList.begin(); itView != c->m_viewList.end(); ++itView) {
+        KtlQCanvasView* view = *itView;
 		view->viewing = 0;
+    }
 }
 
 KtlQCanvas::~KtlQCanvas()
@@ -362,7 +350,7 @@ void KtlQCanvas::resize( const QRect & newSize )
 		return;
 
 	KtlQCanvasItem* item;
-	Q3PtrList<KtlQCanvasItem> hidden;
+	QList<KtlQCanvasItem*> hidden;
 	SortedCanvasItems::iterator end = m_canvasItems.end();
 	for ( SortedCanvasItems::iterator it = m_canvasItems.begin(); it != end; ++it )
 	{
@@ -380,9 +368,13 @@ void KtlQCanvas::resize( const QRect & newSize )
 	delete [] chunks;
 	chunks=newchunks;
 
-	for (item=hidden.first(); item != 0; item=hidden.next()) {
-		item->show();
-	}
+    for (QList<KtlQCanvasItem*>::iterator itItem = hidden.begin(); itItem != hidden.end(); ++itItem) {
+        KtlQCanvasItem* item = *itItem;
+        item->show();
+    }
+// 	for (item=hidden.first(); item != 0; item=hidden.next()) {  // 2018.08.14 - use QList
+// 		item->show();
+// 	}
 
 	setAllChanged();
 
@@ -395,7 +387,7 @@ void KtlQCanvas::retune(int chunksze, int mxclusters)
 
 	if ( chunksize!=chunksze )
 	{
-		Q3PtrList<KtlQCanvasItem> hidden;
+		QList<KtlQCanvasItem*> hidden;
 		SortedCanvasItems::iterator end = m_canvasItems.end();
 		for ( SortedCanvasItems::iterator it = m_canvasItems.begin(); it != end; ++it )
 		{
@@ -414,7 +406,8 @@ void KtlQCanvas::retune(int chunksze, int mxclusters)
 		delete [] chunks;
 		chunks=newchunks;
 
-		for (KtlQCanvasItem* item=hidden.first(); item != 0; item=hidden.next()) {
+		for (QList<KtlQCanvasItem*>::iterator itItem = hidden.begin(); itItem != hidden.end(); ++itItem) {
+            KtlQCanvasItem* item = *itItem;
 			item->show();
 		}
 	}
@@ -441,13 +434,17 @@ void KtlQCanvas::removeItem(const KtlQCanvasItem* item)
 void KtlQCanvas::addView(KtlQCanvasView* view)
 {
 	m_viewList.append(view);
-	if ( htiles>1 || vtiles>1 || pm.isNull() )
-		view->viewport()->setBackgroundColor(backgroundColor());
+	if ( htiles>1 || vtiles>1 || pm.isNull() ) {
+		//view->viewport()->setBackgroundColor(backgroundColor()); // 2018.11.21
+        QPalette palette;
+        palette.setColor(view->viewport()->backgroundRole(), backgroundColor());
+        view->viewport()->setPalette(palette);
+    }
 }
 
 void KtlQCanvas::removeView(KtlQCanvasView* view)
 {
-	m_viewList.removeRef(view);
+    m_viewList.removeAll(view);
 }
 
 void KtlQCanvas::setUpdatePeriod(int ms)
@@ -466,15 +463,15 @@ void KtlQCanvas::setUpdatePeriod(int ms)
 
 // Don't call this unless you know what you're doing.
 // p is in the content's co-ordinate example.
-void KtlQCanvas::drawViewArea( KtlQCanvasView* view, QPainter* p, const QRect& vr, bool dbuf )
+void KtlQCanvas::drawViewArea( KtlQCanvasView* view, QPainter* p, const QRect& vr, bool dbuf /* always false */)
 {
 	QPoint tl = view->contentsToViewport(QPoint(0,0));
 
-	QWMatrix wm = view->worldMatrix();
-	QWMatrix iwm = wm.invert();
+	QMatrix wm = view->worldMatrix();
+	QMatrix iwm = wm.inverted();
     // ivr = covers all chunks in vr
-	QRect ivr = iwm.map(vr);
-	QWMatrix twm;
+	QRect ivr = iwm.mapRect(vr);
+	QMatrix twm;
 	twm.translate(tl.x(),tl.y());
 
 // 	QRect all(0,0,width(),height());
@@ -491,23 +488,26 @@ void KtlQCanvas::drawViewArea( KtlQCanvasView* view, QPainter* p, const QRect& v
 		// For translation-only transformation, it is safe to include the right
 		// and bottom edges, but otherwise, these must be excluded since they
 		// are not precisely defined (different bresenham paths).
-		Q3PointArray a;
+		QPolygon a;
 		if ( wm.m12()==0.0 && wm.m21()==0.0 && wm.m11() == 1.0 && wm.m22() == 1.0 )
-			a = Q3PointArray( QRect(all.x(),all.y(),all.width()+1,all.height()+1) );
-		else	a = Q3PointArray( all );
+			a = QPolygon( QRect(all.x(),all.y(),all.width()+1,all.height()+1) );
+		else	a = QPolygon( all );
 
 		a = (wm*twm).map(a);
 	
-		if ( view->viewport()->backgroundMode() == Qt::NoBackground )
+		//if ( view->viewport()->backgroundMode() == Qt::NoBackground ) // 2018.12.02
+        QWidget *vp = view->viewport();
+        if ( vp->palette().color( vp->backgroundRole() ) == QColor(Qt::transparent) )
 		{
-			QRect cvr = vr; cvr.moveBy(tl.x(),tl.y());
+			QRect cvr = vr; cvr.translate(tl.x(),tl.y());
 			p->setClipRegion(QRegion(cvr)-QRegion(a));
 			p->fillRect(vr,view->viewport()->palette()
-					.brush(QPalette::Active,QColorGroup::Background));
+					.brush(QPalette::Active, QPalette::Window));
 		}
 		p->setClipRegion(a);
 	}
 
+#if 0 // 2018.03.11 - dbuf is always false
 	if ( dbuf ) {
 		offscr = QPixmap(vr.width(), vr.height());
 		offscr.x11SetScreen(p->device()->x11Screen());
@@ -517,19 +517,21 @@ void KtlQCanvas::drawViewArea( KtlQCanvasView* view, QPainter* p, const QRect& v
         if (!isSuccess) {
             qWarning() << Q_FUNC_INFO << " painter not active";
         }
-	
+
 		twm.translate(-vr.x(),-vr.y());
 		twm.translate(-tl.x(),-tl.y());
 		dbp.setWorldMatrix( wm*twm, true );
-	
+
         // 2015.11.27 - do not clip, in order to fix drawing of garbage on the screen.
 		//dbp.setClipRect(0,0,vr.width(), vr.height());
 // 		dbp.setClipRect(v);
 		drawCanvasArea(ivr,&dbp,false);
 		dbp.end();
 		p->drawPixmap(vr.x(), vr.y(), offscr, 0, 0, vr.width(), vr.height());
-	} else {
-		QRect r = vr; r.moveBy(tl.x(),tl.y()); // move to untransformed co-ords
+	} else
+#endif
+    {
+		QRect r = vr; r.translate(tl.x(),tl.y()); // move to untransformed co-ords
 		if ( !all.contains(ivr) )
 		{
 			QRegion inside = p->clipRegion() & r;
@@ -561,14 +563,17 @@ void KtlQCanvas::advance()
 void KtlQCanvas::update()
 {
 	KtlQCanvasClusterizer clusterizer(m_viewList.count());
-	Q3PtrList<QRect> doneareas;
-	doneareas.setAutoDelete(true);
+	QList<QRect> doneareas;
 
-	Q3PtrListIterator<KtlQCanvasView> it(m_viewList);
-	KtlQCanvasView* view;
-	while( (view=it.current()) != 0 ) {
-		++it;
-		QWMatrix wm = view->worldMatrix();
+	//Q3PtrListIterator<KtlQCanvasView> it(m_viewList);   // 2018.08.14 - see below
+	//KtlQCanvasView* view;
+	//while( (view=it.current()) != 0 ) {
+	//	++it;
+    //
+    for (QList<KtlQCanvasView*>::iterator itView = m_viewList.begin(); itView != m_viewList.end(); ++itView) {
+        KtlQCanvasView* view = *itView;
+
+		QMatrix wm = view->worldMatrix();
 	
 		QRect area(view->contentsX(),view->contentsY(),
 				   view->visibleWidth(),view->visibleHeight());
@@ -577,7 +582,7 @@ void KtlQCanvas::update()
 			if ( !wm.isIdentity() )
 			{
 				// r = Visible area of the canvas where there are changes
-				QRect r = changeBounds(view->inverseWorldMatrix().map(area));
+				QRect r = changeBounds(view->inverseWorldMatrix().mapRect(area));
 				if ( !r.isEmpty() )
 				{
                     // as of my testing, drawing below always fails, so just post for an update event to the widget
@@ -594,9 +599,9 @@ void KtlQCanvas::update()
 		  		  // Translate to the coordinate system of drawViewArea().
 					QPoint tl = view->contentsToViewport(QPoint(0,0));
 					p.translate(tl.x(),tl.y());
-					drawViewArea( view, &p, wm.map(r), true );
+// 					drawViewArea( view, &p, wm.map(r), true );
 #endif
-					doneareas.append(new QRect(r));
+					doneareas.append(r);
 				}
 			} else clusterizer.add(area);
 		}
@@ -605,8 +610,11 @@ void KtlQCanvas::update()
 	for (int i=0; i<clusterizer.clusters(); i++)
 		drawChanges(clusterizer[i]);
 
-	for ( QRect* r=doneareas.first(); r != 0; r=doneareas.next() )
-		setUnchanged(*r);
+	//for ( QRect* r=doneareas.first(); r != 0; r=doneareas.next() )        // 2018.08.14 - use iterators
+	//	setUnchanged(*r);
+    for (QList<QRect>::iterator itDone = doneareas.begin(); itDone != doneareas.end(); ++itDone) {
+        setUnchanged( *itDone );
+    }
 }
 
 
@@ -700,12 +708,19 @@ QRect KtlQCanvas::changeBounds(const QRect& inarea)
 	}
 
 	if ( !result.isEmpty() ) {
-		result.rLeft() *= chunksize;
-		result.rTop() *= chunksize;
-		result.rRight() *= chunksize;
-		result.rBottom() *= chunksize;
-		result.rRight() += chunksize;
-		result.rBottom() += chunksize;
+		//result.rLeft() *= chunksize; // 2018.11.18
+		//result.rTop() *= chunksize;
+		//result.rRight() *= chunksize;
+		//result.rBottom() *= chunksize;
+		//result.rRight() += chunksize;
+		//result.rBottom() += chunksize;
+
+        result.setLeft( result.left() * chunksize );
+        result.setTop( result.top() * chunksize );
+        result.setRight( result.right() * chunksize );
+        result.setBottom( result.bottom() * chunksize );
+        result.setRight( result.right() + chunksize );
+        result.setBottom( result.bottom() + chunksize );
 	}
 
 	return result;
@@ -748,7 +763,7 @@ void KtlQCanvas::drawChanges(const QRect& inarea)
 		elarea.width()*chunksize,
 		elarea.height()*chunksize
 					  );
-		drawCanvasArea(elarea);
+		drawCanvasArea(elarea, NULL, /*true*/ false);
 	}
 }
 
@@ -765,14 +780,14 @@ void KtlQCanvas::drawChanges(const QRect& inarea)
 }
 	\endcode
  */
-void KtlQCanvas::drawArea(const QRect& clip, QPainter* painter, bool dbuf)
+void KtlQCanvas::drawArea(const QRect& clip, QPainter* painter)
 {
 	if ( painter )
-		drawCanvasArea( clip, painter, dbuf );
+		drawCanvasArea( clip, painter, false );
 }
 
 
-void KtlQCanvas::drawCanvasArea(const QRect& inarea, QPainter* p, bool double_buffer)
+void KtlQCanvas::drawCanvasArea(const QRect& inarea, QPainter* p, bool double_buffer /* 2018.03.11 - always false */)
 {
 	QRect area=inarea.intersect( m_size );
 
@@ -816,11 +831,11 @@ void KtlQCanvas::drawCanvasArea(const QRect& inarea, QPainter* p, bool double_bu
 	}
 // 	allvisible.sort();
 
+#if 0 // 2018.03.11 - double buffer is always false
 	if ( double_buffer ) {
 		offscr = QPixmap(area.width(), area.height());
 		if (p) offscr.x11SetScreen(p->device()->x11Screen());
 	}
-
 	if ( double_buffer && !offscr.isNull() ) {
 		QPainter painter;
         const bool isSucces = painter.begin(&offscr);
@@ -850,7 +865,9 @@ void KtlQCanvas::drawCanvasArea(const QRect& inarea, QPainter* p, bool double_bu
 			return;
 		}
 
-	} else if ( p ) {
+	} else
+#endif
+    if ( p ) {
 		drawBackground(*p,area);
 // 		allvisible.drawUnique(*p);
 		drawChangedItems( *p );
@@ -862,7 +879,9 @@ void KtlQCanvas::drawCanvasArea(const QRect& inarea, QPainter* p, bool double_bu
 
 	trtr -= area.topLeft();
 
-	for (KtlQCanvasView* view=m_viewList.first(); view; view=m_viewList.next()) {
+	for ( QList<KtlQCanvasView*>::iterator itView = m_viewList.begin(); itView != m_viewList.end(); ++itView) {
+        KtlQCanvasView* view = *itView;
+
 		if ( !view->worldMatrix().isIdentity() )
 			continue; // Cannot paint those here (see callers).
 
@@ -1050,12 +1069,16 @@ void KtlQCanvas::setBackgroundColor( const QColor& c )
 {
 	if ( bgcolor != c ) {
 		bgcolor = c;
-		KtlQCanvasView* view=m_viewList.first();
-		while ( view != 0 ) {
-	    /* XXX this doesn't look right. Shouldn't this
-			be more like setBackgroundPixmap? : Ian */
-			view->viewport()->setEraseColor( bgcolor );
-			view=m_viewList.next();
+		for (QList<KtlQCanvasView*>::iterator itView = m_viewList.begin(); itView != m_viewList.end(); ++itView) {
+            KtlQCanvasView* view = *itView;
+
+            /* XXX this doesn't look right. Shouldn't this
+                be more like setBackgroundPixmap? : Ian */
+            //view->viewport()->setEraseColor( bgcolor ); // 2018.11.21
+            QWidget *viewportWidg = view->viewport();
+            QPalette palette;
+            palette.setColor(viewportWidg->backgroundRole(), bgcolor);
+            viewportWidg->setPalette(palette);
 		}
 		setAllChanged();
 	}
@@ -1081,11 +1104,15 @@ QPixmap KtlQCanvas::backgroundPixmap() const
 void KtlQCanvas::setBackgroundPixmap( const QPixmap& p )
 {
 	setTiles(p, 1, 1, p.width(), p.height());
-	KtlQCanvasView* view = m_viewList.first();
-	while ( view != 0 ) {
-		view->updateContents();
-		view = m_viewList.next();
-	}
+
+    for (QList<KtlQCanvasView*>::iterator itView = m_viewList.begin(); itView != m_viewList.end(); ++itView) {
+        (*itView)->updateContents();
+    }
+	//KtlQCanvasView* view = m_viewList.first();    // 2018.08.14 - see above
+	//while ( view != 0 ) {
+	//	view->updateContents();
+	//	view = m_viewList.next();
+	//}
 }
 
 /*!
@@ -1191,216 +1218,8 @@ void KtlQCanvas::setTile( int x, int y, int tilenum )
 }
 
 
-KtlQCanvasItem::KtlQCanvasItem(KtlQCanvas* canvas)
-	: val(false), myx(0), myy(0), myz(0), cnv(canvas),
-	 ext(0), m_bNeedRedraw(true), vis(false), sel(false)
-{
-    if (isCanvasDebugEnabled()) {
-        qDebug() << Q_FUNC_INFO << " this=" << this;
-    }
-	if (cnv) cnv->addItem(this);
-}
 
 
-KtlQCanvasItem::~KtlQCanvasItem()
-{
-	if (cnv) cnv->removeItem(this);
-	delete ext;
-}
-
-
-KtlQCanvasItemExtra& KtlQCanvasItem::extra()
-{
-	if ( !ext )
-		ext = new KtlQCanvasItemExtra;
-	return *ext;
-}
-
-
-void KtlQCanvasItem::setZ(double a)
-{
-	if ( myz == a )
-		return;
-	
-	// remove and then add the item so that z-ordered list in canvas is updated
-	
-	if (cnv)
-		cnv->removeItem(this);
-
-	myz=a;
-	changeChunks();
-
-	if (cnv)
-		cnv->addItem(this);
-}
-
-
-void KtlQCanvasItem::moveBy(const double dx, const double dy )
-{
-	if ( dx || dy ) {
-		removeFromChunks();
-		myx += dx;
-		myy += dy;
-		addToChunks();
-	}
-}
-
-
-void KtlQCanvasItem::move(const double x, const double y )
-{
-	moveBy( x-myx, y-myy );
-}
-
-
-void KtlQCanvasItem::setCanvas(KtlQCanvas* c)
-{
-	bool v=isVisible();
-	setVisible(false);
-	if (cnv) {
-		cnv->removeItem(this);
-	}
-
-	cnv=c;
-
-	if (cnv) {
-		cnv->addItem(this);
-	}
-
-	setVisible(v);
-}
-
-
-void KtlQCanvasItem::show()
-{
-	setVisible(true);
-}
-
-void KtlQCanvasItem::hide()
-{
-	setVisible(false);
-}
-
-void KtlQCanvasItem::setVisible(bool yes)
-{
-	if (vis != yes) {
-		if (yes) {
-			vis=(uint)yes;
-			addToChunks();
-		} else {
-			removeFromChunks();
-			vis=(uint)yes;
-		}
-	}
-}
-
-
-void KtlQCanvasItem::setSelected(const bool yes)
-{
-	if ((bool)sel!=yes) {
-		sel=(uint)yes;
-		changeChunks();
-	}
-}
-
-
-static bool collision_double_dispatch( const KtlQCanvasPolygonalItem* p1,
-					const KtlQCanvasRectangle* r1,
-					const KtlQCanvasEllipse* e1,
-					const KtlQCanvasPolygonalItem* p2,
-					const KtlQCanvasRectangle* r2,
-					const KtlQCanvasEllipse* e2 )
-{
-    const KtlQCanvasItem *i1 = NULL;
-    if (p1) {
-        i1 = p1;
-    } else {
-        if (r1) {
-            i1 = r1;
-        } else {
-            i1 = e1;
-        }
-    }
-    const KtlQCanvasItem *i2 = NULL;
-    if (i2) {
-        i2 = p2;
-    } else {
-        if (r2) {
-            i2 = r2;
-        } else {
-            i2 = e2;
-        }
-    }
-// 	const KtlQCanvasItem* i1 = p1 ?
-// 			(const KtlQCanvasItem*)p1 : r1 ?
-// 			(const KtlQCanvasItem*)r1 : (const KtlQCanvasItem*)e1;
-// 	const KtlQCanvasItem* i2 = p2 ?
-// 			(const KtlQCanvasItem*)p2 : r2 ?
-// 			(const KtlQCanvasItem*)r2 : (const KtlQCanvasItem*)e2;
-
-	if ( r1 && r2 )
-	{
-		// b
-		QRect rc1 = i1->boundingRect();
-		QRect rc2 = i2->boundingRect();
-		return rc1.intersects(rc2);
-	} else if ( e1 && e2
-			&& e1->angleLength()>=360*16 && e2->angleLength()>=360*16
-			&& e1->width()==e1->height()
-			&& e2->width()==e2->height() )
-	{
-		// c
-		double xd = (e1->x())-(e2->x());
-		double yd = (e1->y())-(e2->y());
-		double rd = (e1->width()+e2->width())/2;
-		return xd*xd+yd*yd <= rd*rd;
-	} else if ( p1 && p2 ) {
-		// d
-		Q3PointArray pa1 = p1->areaPoints();
-		Q3PointArray pa2 = p2 ? p2->areaPoints()
-			: Q3PointArray(i2->boundingRect());
-		bool col= !(QRegion(pa1) & QRegion(pa2,true)).isEmpty();
-
-		return col;
-	} else {
-		return collision_double_dispatch(p2,r2,e2,p1,r1,e1);
-	}
-}
-
-bool KtlQCanvasPolygonalItem::collidesWith( const KtlQCanvasItem* i ) const
-{
-	return i->collidesWith(this,0,0);
-}
-
-bool KtlQCanvasPolygonalItem::collidesWith( const KtlQCanvasPolygonalItem* p, const KtlQCanvasRectangle* r, const KtlQCanvasEllipse* e ) const
-{
-	return collision_double_dispatch(p,r,e,this,0,0);
-}
-
-bool KtlQCanvasRectangle::collidesWith( const KtlQCanvasItem* i ) const
-{
-	return i->collidesWith(this,this,0);
-}
-
-bool KtlQCanvasRectangle::collidesWith( const KtlQCanvasPolygonalItem* p, const KtlQCanvasRectangle* r, const KtlQCanvasEllipse* e ) const
-{
-	return collision_double_dispatch(p,r,e,this,this,0);
-}
-
-bool KtlQCanvasEllipse::collidesWith( const KtlQCanvasItem* i ) const
-{
-	return i->collidesWith(this,0,this);
-}
-
-bool KtlQCanvasEllipse::collidesWith( const KtlQCanvasPolygonalItem* p, const KtlQCanvasRectangle* r, const KtlQCanvasEllipse* e ) const
-{
-	return collision_double_dispatch(p,r,e,this,0,this);
-}
-
-KtlQCanvasItemList KtlQCanvasItem::collisions(const bool exact) const
-{
-	return canvas()->collisions(chunks(),this,exact);
-}
-
 KtlQCanvasItemList KtlQCanvas::collisions(const QPoint& p) /* const */
 {
 	return collisions(QRect(p,QSize(1,1)));
@@ -1418,7 +1237,7 @@ KtlQCanvasItemList KtlQCanvas::collisions(const QRect& r) /* const */
 }
 
 
-KtlQCanvasItemList KtlQCanvas::collisions(const Q3PointArray& chunklist, const KtlQCanvasItem* item, bool exact) const
+KtlQCanvasItemList KtlQCanvas::collisions(const QPolygon& chunklist, const KtlQCanvasItem* item, bool exact) const
 {
     if (isCanvasDebugEnabled()) {
         qDebug() << Q_FUNC_INFO << " test item: " << item;
@@ -1464,71 +1283,20 @@ KtlQCanvasItemList KtlQCanvas::collisions(const Q3PointArray& chunklist, const K
 	return result;
 }
 
-void KtlQCanvasItem::addToChunks()
-{
-	if (isVisible() && canvas()) {
-		Q3PointArray pa = chunks();
-		for (int i=0; i<(int)pa.count(); i++)
-			canvas()->addItemToChunk(this,pa[i].x(),pa[i].y());
-		val = true;
-	}
-}
-
-
-void KtlQCanvasItem::removeFromChunks()
-{
-	if (isVisible() && canvas()) {
-		Q3PointArray pa = chunks();
-		for (int i=0; i<(int)pa.count(); i++)
-			canvas()->removeItemFromChunk(this,pa[i].x(),pa[i].y());
-	}
-}
-
-
-void KtlQCanvasItem::changeChunks()
-{
-	if (isVisible() && canvas()) {
-		if (!val)
-			addToChunks();
-		Q3PointArray pa = chunks();
-		for (int i=0; i<(int)pa.count(); i++)
-			canvas()->setChangedChunk(pa[i].x(),pa[i].y());
-	}
-}
-
-Q3PointArray KtlQCanvasItem::chunks() const
-{
-	Q3PointArray r;
-	int n=0;
-	QRect br = boundingRect();
-	if (isVisible() && canvas())
-	{
-		br &= canvas()->rect();
-		if ( br.isValid() ) {
-			r.resize((canvas()->toChunkScaling( br.width() )+2)*(canvas()->toChunkScaling( br.height() )+2));
-			for (int j=canvas()->toChunkScaling(br.top()); j<=canvas()->toChunkScaling(br.bottom()); j++) {
-				for (int i=canvas()->toChunkScaling(br.left()); i<=canvas()->toChunkScaling(br.right()); i++) {
-					r[n++] = QPoint(i,j);
-				}
-			}
-		}
-	}
-	r.resize(n);
-	return r;
-}
-
-KtlQCanvasView::KtlQCanvasView(QWidget* parent, const char* name, Qt::WFlags f)
-	: Q3ScrollView(parent,name,f|Qt::WResizeNoErase|Qt::WStaticContents)
+KtlQCanvasView::KtlQCanvasView(QWidget* parent, const char* name, Qt::WindowFlags f)
+	: KtlQ3ScrollView(parent,name,f /* |Qt::WResizeNoErase |Qt::WStaticContents */)
 {
+    setAttribute( Qt::WA_StaticContents );
 	d = new KtlQCanvasViewData;
 	viewing = 0;
 	setCanvas(0);
 	connect(this,SIGNAL(contentsMoving(int,int)),this,SLOT(cMoving(int,int)));
 }
 
-KtlQCanvasView::KtlQCanvasView(KtlQCanvas* canvas, QWidget* parent, const char* name, Qt::WFlags f)
-	: Q3ScrollView(parent,name,f|Qt::WResizeNoErase|Qt::WStaticContents)
+KtlQCanvasView::KtlQCanvasView(KtlQCanvas* canvas, QWidget* parent, const char* name, Qt::WindowFlags f)
+	: KtlQ3ScrollView(parent,name,f /* |Qt::WResizeNoErase |Qt::WA_StaticContents */)
 {
+    setAttribute( Qt::WA_StaticContents );
 	d = new KtlQCanvasViewData;
 	viewing = 0;
 	setCanvas(canvas);
@@ -1540,6 +1308,7 @@ KtlQCanvasView::KtlQCanvasView(KtlQCanvas* canvas, QWidget* parent, const char*
 KtlQCanvasView::~KtlQCanvasView()
 {
 	delete d;
+    d = NULL;
 	setCanvas(0);
 }
 
@@ -1560,24 +1329,24 @@ void KtlQCanvasView::setCanvas(KtlQCanvas* canvas)
 }
 
 
-const QWMatrix &KtlQCanvasView::worldMatrix() const
+const QMatrix &KtlQCanvasView::worldMatrix() const
 {
 	return d->xform;
 }
 
 
-const QWMatrix &KtlQCanvasView::inverseWorldMatrix() const
+const QMatrix &KtlQCanvasView::inverseWorldMatrix() const
 {
 	return d->ixform;
 }
 
 
-bool KtlQCanvasView::setWorldMatrix( const QWMatrix & wm )
+bool KtlQCanvasView::setWorldMatrix( const QMatrix & wm )
 {
 	bool ok = wm.isInvertible();
 	if ( ok ) {
 		d->xform = wm;
-		d->ixform = wm.invert();
+		d->ixform = wm.inverted();
 		updateContentsSize();
 		viewport()->update();
 	}
@@ -1589,7 +1358,7 @@ void KtlQCanvasView::updateContentsSize()
 	if ( viewing ) {
 		QRect br;
 // 			br = d->xform.map(QRect(0,0,viewing->width(),viewing->height()));
-		br = d->xform.map(viewing->rect());
+		br = d->xform.mapRect(viewing->rect());
 
 		if ( br.width() < contentsWidth() ) {
 			QRect r(contentsToViewport(QPoint(br.width(),0)),
@@ -1637,11 +1406,11 @@ void KtlQCanvasView::cMoving(int x, int y)
 void KtlQCanvasView::drawContents(QPainter *p, int cx, int cy, int cw, int ch)
 {
 	QRect r(cx,cy,cw,ch);
-	r = r.normalize();
+	r = r.normalized();
 	
 	if (viewing) {
 	//viewing->drawViewArea(this,p,r,true);
-		viewing->drawViewArea(this,p,r,!d->repaint_from_moving);
+		viewing->drawViewArea(this,p,r, /*!d->repaint_from_moving*/ false); /* 2018.03.11 - fix build for osx */
 		d->repaint_from_moving = false;
 	} else {
 		p->eraseRect(r);
@@ -1666,472 +1435,11 @@ void KtlQCanvasView::drawContents( QPainter *p )
 QSize KtlQCanvasView::sizeHint() const
 {
 	if ( !canvas() )
-		return Q3ScrollView::sizeHint();
+		return KtlQ3ScrollView::sizeHint();        // TODO QT3
     // should maybe take transformations into account
 	return ( canvas()->size() + 2 * QSize(frameWidth(), frameWidth()) )
 			.boundedTo( 3 * QApplication::desktop()->size() / 4 );
 }
 
 
-/*
-	Since most polygonal items don't have a pen, the default is
-	NoPen and a black brush.
-*/
-static const QPen& defaultPolygonPen()
-{
-	static QPen* dp=0;
-	if ( !dp )
-		dp = new QPen;
-	return *dp;
-}
-
-static const QBrush& defaultPolygonBrush()
-{
-	static QBrush* db=0;
-	if ( !db )
-		db = new QBrush;
-	return *db;
-}
-
-KtlQCanvasPolygonalItem::KtlQCanvasPolygonalItem(KtlQCanvas* canvas)
-	: KtlQCanvasItem(canvas),
-	br(defaultPolygonBrush()),
-	pn(defaultPolygonPen()), wind(false)
-{
-    if (isCanvasDebugEnabled()) {
-        qDebug() << "created KtlQCanvasPolygonalItem at " << this;
-    }
-}
-
-KtlQCanvasPolygonalItem::~KtlQCanvasPolygonalItem()
-{
-    if (isCanvasDebugEnabled()) {
-        qDebug() << "destroying KtlQCanvasPolygonalItem at " << this;
-    }
-}
-
-bool KtlQCanvasPolygonalItem::winding() const
-{
-	return wind;
-}
-
-void KtlQCanvasPolygonalItem::setWinding(bool enable)
-{
-	wind = enable;
-}
-
-void KtlQCanvasPolygonalItem::invalidate()
-{
-	val = false;
-	removeFromChunks();
-}
-
-
-Q3PointArray KtlQCanvasPolygonalItem::chunks() const
-{
-	Q3PointArray pa = areaPoints();
-
-	if ( !pa.size() )
-	{
-		pa.detach(); // Explicit sharing is stupid.
-		return pa;
-	}
-
-	KtlQPolygonalProcessor processor(canvas(),pa);
-
-	scanPolygon(pa, wind, processor);
-
-	return processor.result;
-}
-
-Q3PointArray KtlQCanvasRectangle::chunks() const
-{
-    // No need to do a polygon scan!
-	return KtlQCanvasItem::chunks();
-}
-
-
-QRect KtlQCanvasPolygonalItem::boundingRect() const
-{
-	return areaPoints().boundingRect();
-}
-
-void KtlQCanvasPolygonalItem::draw(QPainter & p)
-{
-	p.setPen(pn);
-	p.setBrush(br);
-	drawShape(p);
-}
-
-void KtlQCanvasPolygonalItem::setPen( const QPen & p )
-{
-	if ( pn == p )
-		return;
-	
-	pn.setColor( p.color() );
-	
-	// if only the color was different, then don't need to re-add to chunks
-	if ( pn == p ) {
-		changeChunks();
-	} else {
-		// Have to re-add to chunks as e.g. pen width might have changed
-		removeFromChunks();
-		pn = p;
-		addToChunks();
-	}
-}
-
-
-void KtlQCanvasPolygonalItem::setBrush( const QBrush & b )
-{
-	if ( br != b) {
-		br = b;
-		changeChunks();
-	}
-}
-
-
-KtlQCanvasPolygon::KtlQCanvasPolygon(KtlQCanvas* canvas)
-	: KtlQCanvasPolygonalItem(canvas)
-    , guardBef()
-    , poly(new Q3PointArray)
-    , guardAft()
-{
-    if (isCanvasDebugEnabled()) {
-        qDebug() << Q_FUNC_INFO << " this=" << this;
-    }
-}
-
-
-KtlQCanvasPolygon::~KtlQCanvasPolygon()
-{
-	hide();
-    delete poly;
-}
-
-
-void KtlQCanvasPolygon::drawShape(QPainter & p)
-{
-    // ### why can't we draw outlines? We could use drawPolyline for it. Lars
-    // ### see other message. Warwick
-
-    p.setPen(Qt::NoPen); // since QRegion(Q3PointArray) excludes outline :-(  )-:
-	p.drawPolygon(*poly);
-}
-
-
-void KtlQCanvasPolygon::setPoints(Q3PointArray pa)
-{
-	removeFromChunks();
-	*poly = pa;
-	poly->detach(); // Explicit sharing is stupid.
-	poly->translate((int)x(),(int)y());
-	addToChunks();
-}
-
-
-void KtlQCanvasPolygon::moveBy(double dx, double dy)
-{
-    // Note: does NOT call KtlQCanvasPolygonalItem::moveBy(), since that
-    // only does half this work.
-	//
-	int idx = int(x()+dx)-int(x());
-	int idy = int(y()+dy)-int(y());
-	if ( idx || idy ) {
-		removeFromChunks();
-		poly->translate(idx,idy);
-	}
-	myx+=dx;
-	myy+=dy;
-	if ( idx || idy ) {
-		addToChunks();
-	}
-}
-
-Q3PointArray KtlQCanvasPolygon::points() const
-{
-	Q3PointArray pa = areaPoints();
-	pa.translate(int(-x()),int(-y()));
-	return pa;
-}
-
-Q3PointArray KtlQCanvasPolygon::areaPoints() const
-{
-	return poly->copy();
-}
-
-// ### mark: Why don't we offer a constructor that lets the user set the
-// points -- that way for some uses just the constructor call would be
-// required?
-
-KtlQCanvasLine::KtlQCanvasLine(KtlQCanvas* canvas)
-	: KtlQCanvasPolygonalItem(canvas)
-{
-    if (isCanvasDebugEnabled()) {
-        qDebug() << Q_FUNC_INFO << " this=" << this;
-    }
-	x1 = y1 = x2 = y2 = 0;
-}
-
-KtlQCanvasLine::~KtlQCanvasLine()
-{
-	hide();
-}
-
-void KtlQCanvasLine::setPen( const QPen & p )
-{
-	KtlQCanvasPolygonalItem::setPen(p);
-}
-
-void KtlQCanvasLine::setPoints(int xa, int ya, int xb, int yb)
-{
-	if ( x1 != xa || x2 != xb || y1 != ya || y2 != yb ) {
-		removeFromChunks();
-		x1 = xa;
-		y1 = ya;
-		x2 = xb;
-		y2 = yb;
-		addToChunks();
-	}
-}
-
-void KtlQCanvasLine::drawShape(QPainter &p)
-{
-	p.drawLine((int)(x()+x1), (int)(y()+y1), (int)(x()+x2), (int)(y()+y2));
-}
-
-Q3PointArray KtlQCanvasLine::areaPoints() const
-{
-	Q3PointArray p(4);
-	int xi = int(x());
-	int yi = int(y());
-	int pw = pen().width();
-	int dx = abs(x1-x2);
-	int dy = abs(y1-y2);
-	pw = pw*4/3+2; // approx pw*sqrt(2)
-	int px = x1<x2 ? -pw : pw ;
-	int py = y1<y2 ? -pw : pw ;
-	if ( dx && dy && (dx > dy ? (dx*2/dy <= 2) : (dy*2/dx <= 2)) ) {
-	// steep
-		if ( px == py ) {
-			p[0] = QPoint(x1+xi   ,y1+yi+py);
-			p[1] = QPoint(x2+xi-px,y2+yi   );
-			p[2] = QPoint(x2+xi   ,y2+yi-py);
-			p[3] = QPoint(x1+xi+px,y1+yi   );
-		} else {
-			p[0] = QPoint(x1+xi+px,y1+yi   );
-			p[1] = QPoint(x2+xi   ,y2+yi-py);
-			p[2] = QPoint(x2+xi-px,y2+yi   );
-			p[3] = QPoint(x1+xi   ,y1+yi+py);
-		}
-	} else if ( dx > dy ) {
-	// horizontal
-		p[0] = QPoint(x1+xi+px,y1+yi+py);
-		p[1] = QPoint(x2+xi-px,y2+yi+py);
-		p[2] = QPoint(x2+xi-px,y2+yi-py);
-		p[3] = QPoint(x1+xi+px,y1+yi-py);
-	} else {
-	// vertical
-		p[0] = QPoint(x1+xi+px,y1+yi+py);
-		p[1] = QPoint(x2+xi+px,y2+yi-py);
-		p[2] = QPoint(x2+xi-px,y2+yi-py);
-		p[3] = QPoint(x1+xi-px,y1+yi+py);
-	}
-	return p;
-}
-
-void KtlQCanvasLine::moveBy(double dx, double dy)
-{
-	KtlQCanvasPolygonalItem::moveBy(dx, dy);
-}
-
-
-KtlQCanvasRectangle::KtlQCanvasRectangle(KtlQCanvas* canvas) :
-		KtlQCanvasPolygonalItem(canvas),
-    w(32), h(32)
-{
-    setName("KtlQCanvasRectangle");
-    if (isCanvasDebugEnabled()) {
-        qDebug() << Q_FUNC_INFO << " this=" << this;
-    }
-}
-
-
-KtlQCanvasRectangle::KtlQCanvasRectangle(const QRect& r, KtlQCanvas* canvas) :
-		KtlQCanvasPolygonalItem(canvas),
-    w(r.width()), h(r.height())
-{
-    setName("KtlQCanvasRectangle");
-	move(r.x(),r.y());
-    if (isCanvasDebugEnabled()) {
-        qDebug() << Q_FUNC_INFO << " this=" << this;
-    }
-}
-
-
-KtlQCanvasRectangle::KtlQCanvasRectangle(int x, int y, int width, int height, KtlQCanvas* canvas)
-	: KtlQCanvasPolygonalItem(canvas),
-	w(width), h(height)
-{
-    setName("KtlQCanvasRectangle");
-	move(x,y);
-    if (isCanvasDebugEnabled()) {
-        qDebug() << Q_FUNC_INFO << " this=" << this;
-    }
-}
-
-
-KtlQCanvasRectangle::~KtlQCanvasRectangle()
-{
-	hide();
-}
-
-
-int KtlQCanvasRectangle::width() const
-{
-	return w;
-}
-
-int KtlQCanvasRectangle::height() const
-{
-	return h;
-}
-
-
-void KtlQCanvasRectangle::setSize(const int width, const int height)
-{
-	if ( w != width || h != height ) {
-		removeFromChunks();
-		w = width;
-		h = height;
-		addToChunks();
-	}
-}
-
-
-Q3PointArray KtlQCanvasRectangle::areaPoints() const
-{
-	Q3PointArray pa(4);
-	int pw = (pen().width()+1)/2;
-	if ( pw < 1 ) pw = 1;
-	if ( pen() == Qt::NoPen ) pw = 0;
-	pa[0] = QPoint((int)x()-pw,(int)y()-pw);
-	pa[1] = pa[0] + QPoint(w+pw*2,0);
-	pa[2] = pa[1] + QPoint(0,h+pw*2);
-	pa[3] = pa[0] + QPoint(0,h+pw*2);
-	return pa;
-}
-
-
-void KtlQCanvasRectangle::drawShape(QPainter &p)
-{
-	p.drawRect((int)x(), (int)y(), w, h);
-}
-
-
-KtlQCanvasEllipse::KtlQCanvasEllipse(KtlQCanvas* canvas)
-	: KtlQCanvasPolygonalItem(canvas),
-	w(32), h(32),
-	a1(0), a2(360*16)
-{
-    if (isCanvasDebugEnabled()) {
-        qDebug() << Q_FUNC_INFO << " this=" << this;
-    }
-}
-
-/*!
-	Constructs a \a width by \a height pixel ellipse, centered at
-	(0, 0) on \a canvas.
- */
-	KtlQCanvasEllipse::KtlQCanvasEllipse(int width, int height, KtlQCanvas* canvas)
-	: KtlQCanvasPolygonalItem(canvas),
-	w(width),h(height),
-	a1(0),a2(360*16)
-{
-    if (isCanvasDebugEnabled()) {
-        qDebug() << Q_FUNC_INFO << " this=" << this;
-    }
-}
-
-
-KtlQCanvasEllipse::KtlQCanvasEllipse(int width, int height,
-    int startangle, int angle, KtlQCanvas* canvas) :
-			KtlQCanvasPolygonalItem(canvas),
-	w(width),h(height),
-	a1(startangle),a2(angle)
-{
-    if (isCanvasDebugEnabled()) {
-        qDebug() << Q_FUNC_INFO << " this=" << this;
-    }
-}
-
-
-KtlQCanvasEllipse::~KtlQCanvasEllipse()
-{
-	hide();
-}
-
-
-int KtlQCanvasEllipse::width() const
-{
-	return w;
-}
-
-
-int KtlQCanvasEllipse::height() const
-{
-	return h;
-}
-
-
-void KtlQCanvasEllipse::setSize(int width, int height)
-{
-	if ( w != width || h != height ) {
-		removeFromChunks();
-		w = width;
-		h = height;
-		addToChunks();
-	}
-}
-
-
-void KtlQCanvasEllipse::setAngles(int start, int length)
-{
-	if ( a1 != start || a2 != length ) {
-		removeFromChunks();
-		a1 = start;
-		a2 = length;
-		addToChunks();
-	}
-}
-
-
-Q3PointArray KtlQCanvasEllipse::areaPoints() const
-{
-	Q3PointArray r;
-    // makeArc at 0,0, then translate so that fixed point math doesn't overflow
-	r.makeArc(int(x()-w/2.0+0.5)-1, int(y()-h/2.0+0.5)-1, w+3, h+3, a1, a2);
-	r.resize(r.size()+1);
-	r.setPoint(r.size()-1,int(x()),int(y()));
-	return r;
-}
-
-
-void KtlQCanvasEllipse::drawShape(QPainter & p)
-{
-    p.setPen(Qt::NoPen); // since QRegion(Q3PointArray) excludes outline :-(  )-:
-	if ( !a1 && a2 == 360*16 ) {
-		p.drawEllipse(int(x()-w/2.0+0.5), int(y()-h/2.0+0.5), w, h);
-	} else {
-		p.drawPie(int(x()-w/2.0+0.5), int(y()-h/2.0+0.5), w, h, a1, a2);
-	}
-}
-
-
-void KtlQCanvasPolygonalItem::scanPolygon(const Q3PointArray& pa, int winding, KtlQPolygonalProcessor& process) const
-{
-	KtlQCanvasPolygonScanner scanner(process);
-	scanner.scan(pa,winding);
-}
-
 #include "canvas.moc"
