@@ -75,9 +75,12 @@ CircuitDocument::~CircuitDocument()
         disconnect( connector, SIGNAL(removed(Connector*)), this, SLOT(requestAssignCircuits()) );
     }
     for (ItemMap::Iterator itItem = m_itemList.begin(); itItem != m_itemList.end(); ++itItem) {
-        Item *item = itItem.data();
+        Item *item = itItem.value();
         disconnect( item, SIGNAL(removed(Item*)), this, SLOT(componentRemoved(Item*)) );
-        disconnect( item, SIGNAL(elementDestroyed(Element*)), this, SLOT(requestAssignCircuits()) );
+        Component *comp = dynamic_cast<Component*>( item );
+        if ( comp ) {
+            disconnect( comp, SIGNAL(elementDestroyed(Element*)), this, SLOT(requestAssignCircuits()) );
+        }
     }
 
     deleteCircuits();
@@ -97,7 +100,7 @@ void CircuitDocument::slotInitItemActions( )
 	
 	Component *item = dynamic_cast<Component*>( m_selectList->activeItem() );
 	
-	if ( !item && m_selectList->count() > 0 || !m_selectList->itemsAreSameType() )
+	if ( (!item && m_selectList->count() > 0) || !m_selectList->itemsAreSameType() )
 		return;
 	
 	QAction * orientation_actions[] = {
@@ -263,7 +266,7 @@ void CircuitDocument::fillContextMenu( const QPoint &pos )
 
 	// NOTE: I negated this whole condition because I couldn't make out quite what the
 	//logic was --electronerd
-	if (!( !item && m_selectList->count() > 0 || !m_selectList->itemsAreSameType() ))
+	if (!( (!item && m_selectList->count() > 0) || !m_selectList->itemsAreSameType() ))
 	{	
 		QAction * orientation_actions[] = {
 			activeCircuitView->actionByName("edit_orientation_0"),
@@ -311,7 +314,8 @@ void CircuitDocument::requestAssignCircuits()
     }
 	deleteCircuits();
 	m_updateCircuitsTmr->stop();
-	m_updateCircuitsTmr->start( 0, true );
+    m_updateCircuitsTmr->setSingleShot( true );
+	m_updateCircuitsTmr->start( 0 /*, true */ );
 }
 
 
@@ -357,8 +361,8 @@ void CircuitDocument::componentRemoved( Item * item )
 
 	if (!component) return;
 
-	m_componentList.remove( component );
-	m_toSimulateList.remove( component );
+	m_componentList.removeAll( component );
+	m_toSimulateList.removeAll( component );
 
 	requestAssignCircuits();
 
@@ -379,7 +383,7 @@ void CircuitDocument::calculateConnectorCurrents()
 	PinList groundPins;
 
 	// Tell the Pins to reset their calculated currents to zero
-	m_pinList.remove((Pin*)0);
+	m_pinList.removeAll((Pin*)0);
 
 	const PinList::iterator pinEnd = m_pinList.end();
 	for ( PinList::iterator it = m_pinList.begin(); it != pinEnd; ++it )
@@ -410,7 +414,7 @@ void CircuitDocument::calculateConnectorCurrents()
 
 
 	// And now for the wires and switches...
-	m_wireList.remove((Wire*)0);
+	m_wireList.removeAll((Wire*)0);
 	const WireList::iterator clEnd = m_wireList.end();
 	for ( WireList::iterator it = m_wireList.begin(); it != clEnd; ++it )
 		(*it)->setCurrentKnown(false);
@@ -444,7 +448,7 @@ void CircuitDocument::calculateConnectorCurrents()
                 // it = container.erase( it ) seems to crash other times
 				SwitchList::iterator oldIt = it;
 				++it;
-				switches.remove(oldIt);
+				switches.erase(oldIt);
 			} else ++it;
 		}
 
@@ -460,7 +464,7 @@ make the ground pins work. Current engine doesn't treat ground explicitly.
                 // it = container.erase( it ) seems to crash other times
 				PinList::iterator oldIt = it;
 				++it;
-				groundPins.remove(oldIt);
+				groundPins.erase(oldIt);
 			} else ++it;
 		}
 	}
@@ -520,7 +524,7 @@ void CircuitDocument::assignCircuits()
 		splitIntoCircuits(&*it);
 	
 	// Stage 3: Initialize the circuits
-	m_circuitList.remove(0l);
+	m_circuitList.removeAll(0l);
 	CircuitList::iterator circuitListEnd = m_circuitList.end();
 	for ( CircuitList::iterator it = m_circuitList.begin(); it != circuitListEnd; ++it )
 		(*it)->init();
@@ -563,7 +567,7 @@ void CircuitDocument::getPartition( Pin *pin, PinList *pinList, PinList *unassig
 {
 	if (!pin) return;
 	
-	unassignedPins->remove(pin);
+	unassignedPins->removeAll(pin);
 	
 	if ( pinList->contains(pin) ) return;
 
@@ -649,7 +653,7 @@ void CircuitDocument::recursivePinAdd( Pin *pin, Circuitoid *circuitoid, PinList
 	if(!pin) return;
 	
 	if(pin->eqId() != -1 )
-		unassignedPins->remove(pin);
+		unassignedPins->removeAll(pin);
 
 	if(circuitoid->contains(pin) ) return;
 
@@ -770,7 +774,7 @@ void CircuitDocument::createSubcircuit()
 			*it = 0;
 	}
 
-	itemList.remove((Item*)0);
+	itemList.removeAll((Item*)0);
 	
 	if ( itemList.isEmpty() ) {
 		KMessageBox::sorry( activeView(), i18n("No components were found in the selection.") );
