@@ -42,7 +42,7 @@
 #include <qbitarray.h>
 #include <qpainter.h>
 #include <qwidget.h>
-#include <qwmatrix.h>
+#include <qmatrix.h>
 
 #include <ktlconfig.h>
 
@@ -135,7 +135,7 @@ void Component::removeElement( Element * element, bool setPinsInterIndependent )
         ++next;
 
         if ( (*it).e == element )
-            m_elementMapList.remove(it);
+            m_elementMapList.erase(it);
 
         it = next;
     }
@@ -150,7 +150,7 @@ void Component::removeSwitch( Switch *sw )
 
     emit switchDestroyed( sw );
     delete sw;
-    m_switchList.remove(sw);
+    m_switchList.removeAll(sw);
     m_pCircuitDocument->requestAssignCircuits();
 }
 
@@ -239,7 +239,7 @@ void Component::setFlipped( bool flipped )
 
 void Component::itemPointsChanged()
 {
-    Q3PointArray transformedPoints = transMatrix( m_angleDegrees, b_flipped, 0, 0, false ).map(m_itemPoints);
+    QPolygon transformedPoints = transMatrix( m_angleDegrees, b_flipped, 0, 0, false ).map(m_itemPoints);
 // 	transformedPoints.translate( int(x()), int(y()) );
     setPoints(transformedPoints);
 }
@@ -263,9 +263,9 @@ ItemData Component::itemData() const
 }
 
 
-QWMatrix Component::transMatrix( int angleDegrees, bool flipped, int x, int y, bool inverse )
+QMatrix Component::transMatrix( int angleDegrees, bool flipped, int x, int y, bool inverse )
 {
-    QWMatrix m;
+    QMatrix m;
     m.translate( x, y );
     if (inverse)
     {
@@ -280,7 +280,7 @@ QWMatrix Component::transMatrix( int angleDegrees, bool flipped, int x, int y, b
         m.rotate(angleDegrees);
     }
     m.translate( -x, -y );
-    // m.setTransformationMode( QWMatrix::Areas ); // TODO find a replacement
+    // m.setTransformationMode( QMatrix::Areas ); // TODO find a replacement
     return m;
 }
 
@@ -303,12 +303,12 @@ void Component::updateAttachedPositioning()
     const NodeInfoMap::iterator end = m_nodeMap.end();
     for ( NodeInfoMap::iterator it = m_nodeMap.begin(); it != end; ++it )
     {
-        if ( !it.data().node )
+        if ( !it.value().node )
             kError() << k_funcinfo << "Node in nodemap is null" << endl;
         else
         {
-            int nx = int((std::cos(m_angleDegrees * RPD) * it.data().x) - (std::sin(m_angleDegrees * RPD) * it.data().y));
-            int ny = int((std::sin(m_angleDegrees * RPD) * it.data().x) + (std::cos(m_angleDegrees * RPD) * it.data().y));
+            int nx = int((std::cos(m_angleDegrees * RPD) * it.value().x) - (std::sin(m_angleDegrees * RPD) * it.value().y));
+            int ny = int((std::sin(m_angleDegrees * RPD) * it.value().x) + (std::cos(m_angleDegrees * RPD) * it.value().y));
 
             if (b_flipped)
                 nx = -nx;
@@ -318,40 +318,40 @@ void Component::updateAttachedPositioning()
             ny = round_8(ny);
 #undef round_8
 
-            int newDir = (((m_angleDegrees + it.data().orientation)%360)+360)%360;
+            int newDir = (((m_angleDegrees + it.value().orientation)%360)+360)%360;
             if (b_flipped)
                 newDir = (((180-newDir)%360)+360)%360;
 
-            it.data().node->move( nx+x(), ny+y() );
-            it.data().node->setOrientation( newDir );
+            it.value().node->move( nx+x(), ny+y() );
+            it.value().node->setOrientation( newDir );
         }
     }
     //END Transform the nodes
 
 
     //BEGIN Transform the GuiParts
-    QWMatrix m;
+    QMatrix m;
 
     if (b_flipped)
         m.scale( -1, 1 );
     m.rotate(m_angleDegrees);
-    //m.setTransformationMode( QWMatrix::Areas ); // TODO find a replacement
+    //m.setTransformationMode( QMatrix::Areas ); // TODO find a replacement
 
     const TextMap::iterator textMapEnd = m_textMap.end();
     for ( TextMap::iterator it = m_textMap.begin(); it != textMapEnd; ++it )
     {
-        QRect newPos = m.mapRect( it.data()->recommendedRect() );
-        it.data()->move( newPos.x() + x(), newPos.y() + y() );
-        it.data()->setGuiPartSize( newPos.width(), newPos.height() );
-        it.data()->setAngleDegrees(m_angleDegrees);
+        QRect newPos = m.mapRect( it.value()->recommendedRect() );
+        it.value()->move( newPos.x() + x(), newPos.y() + y() );
+        it.value()->setGuiPartSize( newPos.width(), newPos.height() );
+        it.value()->setAngleDegrees(m_angleDegrees);
     }
     const WidgetMap::iterator widgetMapEnd = m_widgetMap.end();
     for ( WidgetMap::iterator it = m_widgetMap.begin(); it != widgetMapEnd; ++it )
     {
-        QRect newPos = m.mapRect( it.data()->recommendedRect() );
-        it.data()->move( newPos.x() + x(), newPos.y() + y() );
-        it.data()->setGuiPartSize( newPos.width(), newPos.height() );
-        it.data()->setAngleDegrees(m_angleDegrees);
+        QRect newPos = m.mapRect( it.value()->recommendedRect() );
+        it.value()->move( newPos.x() + x(), newPos.y() + y() );
+        it.value()->setGuiPartSize( newPos.width(), newPos.height() );
+        it.value()->setAngleDegrees(m_angleDegrees);
     }
     //END Transform the GuiParts
 }
@@ -870,7 +870,7 @@ MOSFET * Component::createMOSFET( Pin * D, Pin * G, Pin * S, Pin * B, int MOSFET
     pins << D << G << S << B;
 
     /// \todo remove the following line removing body if null
-    pins.remove( 0 );
+    pins.removeAll( 0 );
 
     ElementMapList::iterator it = handleElement( e, pins );
     setInterDependent( it, pins );
@@ -1072,10 +1072,10 @@ void Component::setAllPinsInterIndependent()
     NodeInfoMap::iterator nmEnd = m_nodeMap.end();
     for ( NodeInfoMap::iterator it = m_nodeMap.begin(); it != nmEnd; ++it )
     {
-        //PinVector pins = (static_cast<ECNode*>(it.data().node))->pins();
-        ECNode *node = dynamic_cast<ECNode*>(it.data().node);
+        //PinVector pins = (static_cast<ECNode*>(it.value().node))->pins();
+        ECNode *node = dynamic_cast<ECNode*>(it.value().node);
         if (!node) {
-            qWarning() << Q_FUNC_INFO << "skipping not-ECNode node: " << it.data().node;
+            qWarning() << Q_FUNC_INFO << "skipping not-ECNode node: " << it.value().node;
             continue;
         }
         PinVector pins = node->pins();
