@@ -14,7 +14,7 @@
 #include <component.h>
 
 #include <qpointer.h>
-#include <q3valuevector.h>
+// #include <q3valuevector.h>
 
 class Wire;
 
@@ -36,7 +36,7 @@ class BusSplitter : public Component
 		virtual void drawShape( QPainter &p );
 		
 		unsigned m_busSize;
-		Q3ValueVector<QPointer<Wire> > m_pWires;
+		QVector<QPointer<Wire> > m_pWires;
 		ECNode * m_pInNode;
 };
 
