@@ -14,7 +14,7 @@
 #include "component.h"
 #include "logic.h"
 
-#include <q3ptrvector.h>
+// #include <q3ptrvector.h> // 2018.10.17
 
 /**
 @author David Saxton
@@ -37,8 +37,8 @@ protected:
 	
 	void inStateChanged( bool newState );
 	
-	Q3PtrVector<LogicIn> m_aLogic;
-	Q3PtrVector<LogicOut> m_xLogic;
+	QVector<LogicIn*> m_aLogic;
+	QVector<LogicOut*> m_xLogic;
 	LogicIn * m_input;
 };
 
