@@ -29,9 +29,9 @@ class MatrixDisplayDriver : public Component
 		virtual bool doesStepNonLogic() const { return true; }
 		
 	protected:
-		Q3ValueVector<LogicIn*> m_pValueLogic;
-		Q3ValueVector<LogicOut*> m_pRowLogic;
-		Q3ValueVector<LogicOut*> m_pColLogic;
+		QVector<LogicIn*> m_pValueLogic;
+		QVector<LogicOut*> m_pRowLogic;
+		QVector<LogicOut*> m_pColLogic;
 		
 		unsigned m_prevCol;
 		unsigned m_nextCol;
