@@ -61,7 +61,7 @@ function will remove the duplicated directory path (by searching for a "//").
 */
 QString sanitizeGpsimFile( QString file )
 {
-	int pos = file.find("//");
+	int pos = file.indexOf("//");
 	if ( pos != -1 )
 	{
 		file.remove( 0, pos + 1 );
@@ -91,7 +91,7 @@ GpsimProcessor::GpsimProcessor( QString symbolFile, QObject *parent )
 	m_pDebugger[0] = m_pDebugger[1] = 0l;
 	
 	Processor * tempProcessor = 0l;
-	const char * fileName = symbolFile.ascii();
+	const char * fileName = symbolFile.toAscii();
 	
 #ifdef GPSIM_0_21_4
     qDebug() << "GPSIM_0_21_4 GpsimProcessor " << fileName;
@@ -314,7 +314,7 @@ GpsimProcessor::ProgramFileValidity GpsimProcessor::isValidProgramFile( const QS
 	if ( !KStandardDirs::exists(programFile) )
 		return DoesntExist;
 	
-	QString extension = programFile.right( programFile.length() - programFile.findRev('.') - 1 ).lower();
+	QString extension = programFile.right( programFile.length() - programFile.lastIndexOf('.') - 1 ).toLower();
 	
 	if ( extension == "flowcode" ||
 			extension == "asm" ||
@@ -338,7 +338,7 @@ QString GpsimProcessor::generateSymbolFile( const QString &fileName, QObject *re
 		return QString::null;
     }
 	
-	QString extension = fileName.right( fileName.length() - fileName.findRev('.') - 1 ).lower();
+	QString extension = fileName.right( fileName.length() - fileName.lastIndexOf('.') - 1 ).toLower();
 	
 	if ( extension == "cod" )
 	{
@@ -566,10 +566,10 @@ void GpsimDebugger::initAddressToLineMap()
 		
 			QString asmFile = it.key().fileName();
 			int asmFromLine = it.key().line();
-			SourceLine sourceLine = it.data();
+			SourceLine sourceLine = it.value();
 			
 			
-			std::string stdAsmFile( asmFile.ascii() );
+			std::string stdAsmFile( asmFile.toAscii() );
 			int fileID = m_pGpsim->picProcessor()->files.Find( stdAsmFile );
 			if ( fileID == -1 )
 			{
@@ -747,12 +747,13 @@ RegisterSet::RegisterSet( pic_processor * picProcessor )
 {
 	unsigned numRegisters = picProcessor->rma.get_size();
 	kDebug() << k_funcinfo << "numRegisters="<<numRegisters<<endl;
-	m_registers.resize( numRegisters, 0l );
+	m_registers.resize( numRegisters /*, 0l - 2018.06.02 - initialized below */ );
 	for ( unsigned i = 0; i < numRegisters; ++i )
 	{
 		RegisterInfo * info = new RegisterInfo( & picProcessor->rma[i] );
 		m_registers[i] = info;
 		m_nameToRegisterMap[ info->name() ] = info;
+        qDebug() << Q_FUNC_INFO << " add register info " << info->name() << " at pos " << i << " addr " << info;
 	}
 #if defined(HAVE_GPSIM_0_26)
 	RegisterInfo * info = new RegisterInfo( picProcessor->Wreg ); // is tihs correct for "W" member? TODO
@@ -761,6 +762,8 @@ RegisterSet::RegisterSet( pic_processor * picProcessor )
 #endif
 	m_registers.append( info );
 	m_nameToRegisterMap[ info->name() ] = info;
+    qDebug() << Q_FUNC_INFO << " add register info " << info->name() << " at end, addr " << info;
+    qDebug() << Q_FUNC_INFO << " registers.size " << m_registers.size() << " ; numRegisters " << numRegisters;
 }
 
 
@@ -783,13 +786,13 @@ RegisterInfo * RegisterSet::fromName( const QString & name )
 	if ( m_nameToRegisterMap.contains( name ) )
 		return m_nameToRegisterMap[ name ];
 	
-	QString nameLower = name.lower();
+	QString nameLower = name.toLower();
 	
 	RegisterInfoMap::iterator end = m_nameToRegisterMap.end();
 	for ( RegisterInfoMap::iterator it = m_nameToRegisterMap.begin(); it != end; ++ it )
 	{
-		if ( it.key().lower() == nameLower )
-			return it.data();
+		if ( it.key().toLower() == nameLower )
+			return it.value();
 	}
 	
 	return 0l;
@@ -832,7 +835,7 @@ RegisterInfo::RegisterInfo( Register * reg )
 			break;
 	}
 		
-	m_name = m_pRegister->baseName().c_str();
+	m_name = QString::fromLatin1(m_pRegister->baseName().c_str());
 }
 
 
