@@ -25,7 +25,7 @@ JunctionNode::JunctionNode(ICNDocument* icnDocument, int dir, const QPoint& pos,
     } else {
         name.append("-Unknown");
     }
-    setName( name.toLatin1().data() );
+    setObjectName( name.toLatin1().data() );
 }
 
 
@@ -58,5 +58,5 @@ void JunctionNode::drawShape( QPainter & p )
 
 void JunctionNode::initPoints()
 {
-	setPoints( Q3PointArray( QRect( -4, -4, 8, 8 ) ) );
+	setPoints( QPolygon( QRect( -4, -4, 8, 8 ) ) );
 }
