@@ -95,7 +95,7 @@ FlowPart::~FlowPart()
 		const VariantDataMap::iterator end = m_variantData.end();
 		for ( VariantDataMap::iterator it = m_variantData.begin(); it != end; ++it )
 		{
-			Variant *v = it.data();
+			Variant *v = it.value();
 			if (v)
 				m_pFlowCodeDocument->varNameChanged( "", v->value().toString() );
 		}
@@ -125,7 +125,7 @@ void FlowPart::setCaption( const QString &caption )
 // 	delete w;
 
     QFontMetrics fontMetrics( font() );
-    const int text_width = fontMetrics.boundingRect( boundingRect(), (Qt::SingleLine | Qt::AlignHCenter | Qt::AlignVCenter), caption ).width();
+    const int text_width = fontMetrics.boundingRect( boundingRect(), (Qt::TextSingleLine | Qt::AlignHCenter | Qt::AlignVCenter), caption ).width();
 
 	int width = std::max( ((int)(text_width/16))*16, 48 );
 	
@@ -191,7 +191,7 @@ void FlowPart::initSymbol( FlowPart::FlowSymbol symbol, int width )
 		case FlowPart::ps_io:
 		{
 			// define parallelogram shape
-			Q3PointArray pa(4);
+			QPolygon pa(4);
 			pa[0] = QPoint( -(width-10)/2, -16 );
 			pa[1] = QPoint( width/2, -16 );
 			pa[2] = QPoint( (width-10)/2, 8 );
@@ -210,7 +210,7 @@ void FlowPart::initSymbol( FlowPart::FlowSymbol symbol, int width )
 			// Draw semicircle
 			double x;
 			const int RP_NUM = 48;
-			Q3PointArray pa(RP_NUM);
+			QPolygon pa(RP_NUM);
 			int point = 0;
 			for ( double y = -1.0; y <= 1.0; y+= 4.0/(RP_NUM-2) )
 			{
@@ -228,7 +228,7 @@ void FlowPart::initSymbol( FlowPart::FlowSymbol symbol, int width )
 		case FlowPart::ps_decision:
 		{
 			// define rhombus
-			Q3PointArray pa(6);
+			QPolygon pa(6);
 			pa[0] = QPoint( 0, -24 );
 			pa[1] = QPoint( width/2, -6 );
 			pa[2] = QPoint( width/2, 6 );
@@ -335,7 +335,7 @@ void FlowPart::drawShape( QPainter &p )
 	
 	p.setPen( Qt::black );
 	p.setFont( font() );
-	p.drawText( boundingRect(), (Qt::WordBreak | Qt::AlignHCenter | Qt::AlignVCenter), m_caption );
+	p.drawText( boundingRect(), (Qt::TextWordWrap | Qt::AlignHCenter | Qt::AlignVCenter), m_caption );
 }
 
 QString FlowPart::gotoCode( const QString& internalNodeId )
@@ -375,7 +375,7 @@ FlowPartList FlowPart::inputParts()
 	const NodeInfoMap::iterator nEnd = m_nodeMap.end();
 	for ( NodeInfoMap::iterator it = m_nodeMap.begin(); it != nEnd; ++it )
 	{
-		Node *node = p_icnDocument->nodeWithID( it.data().id );
+		Node *node = p_icnDocument->nodeWithID( it.value().id );
 		FlowPartList newList;
 		
 		if ( FPNode *fpNode = dynamic_cast<FPNode*>(node) )
@@ -500,7 +500,7 @@ void FlowPart::handleIfElse( FlowCode *code, const QString &case1Statement, cons
 	FlowPart *part1 = outputPart(case1);
 	FlowPart *part2 = outputPart(case2);
 	
-	if ( part1 && part2 ) stop = endPart( QStringList::split( ',', case1+","+case2 ) );
+	if ( part1 && part2 ) stop = endPart( (QStringList(case1) << case2 ) );
 	
 	if ( (!part1 && !part2) || (part1 == stop && part2 == stop) ) return;
 	
@@ -573,7 +573,7 @@ void FlowPart::slotUpdateFlowPartVariables()
 	PinMappingMap::const_iterator pEnd = pinMappings.end();
 	for ( PinMappingMap::const_iterator it = pinMappings.begin(); it != pEnd; ++it )
 	{
-		switch ( it.data().type() )
+		switch ( it.value().type() )
 		{
 		case PinMapping::SevenSegment:
 			sevenSegMaps << it.key();
@@ -598,7 +598,7 @@ void FlowPart::slotUpdateFlowPartVariables()
 	const VariantDataMap::iterator vEnd = m_variantData.end();
 	for ( VariantDataMap::iterator it = m_variantData.begin(); it != vEnd; ++it )
 	{
-		Variant * v = it.data();
+		Variant * v = it.value();
 		if ( !v ) continue;
 		
 		if ( v->type() == Variant::Type::Port )
@@ -629,7 +629,7 @@ void FlowPart::updateVarNames()
 	const VariantDataMap::iterator end = m_variantData.end();
 	for ( VariantDataMap::iterator it = m_variantData.begin(); it != end; ++it )
 	{
-		Variant *v = it.data();
+		Variant *v = it.value();
 		if ( v && v->type() == Variant::Type::VarName )
 			v->setAllowed(names);
 	}
@@ -639,7 +639,7 @@ void FlowPart::varNameChanged( QVariant newValue, QVariant oldValue )
 {
 	if (!m_pFlowCodeDocument)
 		return;
-	m_pFlowCodeDocument->varNameChanged( newValue.asString(), oldValue.asString() );
+	m_pFlowCodeDocument->varNameChanged( newValue.toString(), oldValue.toString() );
 }
 
 inline int nodeDirToPos( int dir )
@@ -684,31 +684,31 @@ void FlowPart::updateAttachedPositioning( )
 	const TextMap::iterator textMapEnd = m_textMap.end();
 	for ( TextMap::iterator it = m_textMap.begin(); it != textMapEnd; ++it )
 	{
-		QRect pos = it.data()->recommendedRect();
-		it.data()->move( pos.x() + x(), pos.y() + y() );
-		it.data()->setGuiPartSize( pos.width(), pos.height() );
+		QRect pos = it.value()->recommendedRect();
+		it.value()->move( pos.x() + x(), pos.y() + y() );
+		it.value()->setGuiPartSize( pos.width(), pos.height() );
 	}
 	//END Rearrange text if appropriate
 	
 	const NodeInfoMap::iterator end = m_nodeMap.end();
 	for ( NodeInfoMap::iterator it = m_nodeMap.begin(); it != end; ++it )
 	{
-		if ( !it.data().node )
+		if ( !it.value().node )
 		{
 			kError() << k_funcinfo << "Node in nodemap is null" << endl;
 			continue;
 		}
 		
-		double nx = it.data().x;
-		double ny = it.data().y;
+		double nx = it.value().x;
+		double ny = it.value().y;
 			
 #define round_8(x) (((x) > 0) ? int(((x)+4)/8)*8 : int(((x)-4)/8)*8)
 		nx = round_8(nx);
 		ny = round_8(ny);
 #undef round_8
 			
-		it.data().node->move( int(nx+x()), int(ny+y()) );
-		it.data().node->setOrientation( it.data().orientation );
+		it.value().node->move( int(nx+x()), int(ny+y()) );
+		it.value().node->setOrientation( it.value().orientation );
 	}
 }
 
@@ -758,25 +758,25 @@ void FlowPart::updateNodePositions()
 	const NodeInfoMap::iterator end = m_nodeMap.end();
 	for ( NodeInfoMap::iterator it = m_nodeMap.begin(); it != end; ++it )
 	{
-		if ( !it.data().node )
+		if ( !it.value().node )
 			kError() << k_funcinfo << "Node in nodemap is null" << endl;
 		else {
-			switch ( it.data().orientation ) {
+			switch ( it.value().orientation ) {
 			case 0:
-				it.data().x = offsetX()+width()+8;
-				it.data().y = 0;
+				it.value().x = offsetX()+width()+8;
+				it.value().y = 0;
 				break;
 			case 270:
-				it.data().x = 0;
-				it.data().y = offsetY()-8;
+				it.value().x = 0;
+				it.value().y = offsetY()-8;
 				break;
 			case 180:
-				it.data().x = offsetX()-8;
-				it.data().y = 0;
+				it.value().x = offsetX()-8;
+				it.value().y = 0;
 				break;
 			case 90:
-				it.data().x = 0;
-				it.data().y = offsetY()+height()+8;;
+				it.value().x = 0;
+				it.value().y = offsetY()+height()+8;;
 				break;
 			}
 		}
@@ -866,7 +866,7 @@ void FlowPart::orientationPixmap( uint orientation, QPixmap & pm ) const
 	if ( m_stdInput && m_stdOutput && m_altOutput )
 	{
 		//BEGIN Draw diamond outline
-		Q3PointArray diamond(4);
+		QPolygon diamond(4);
 		for ( uint i=0; i<4; ++i )
 			diamond[i] = c[i];
 		
@@ -883,7 +883,7 @@ void FlowPart::orientationPixmap( uint orientation, QPixmap & pm ) const
 		
 		
 		//BEGIN Draw "true" output as a tick
-		Q3PointArray tick(4);
+		QPolygon tick(4);
 		tick[0] = QPoint( -3, 0 );
 		tick[1] = QPoint( 0, 2 );
 		tick[2] = QPoint( 0, 2 );
@@ -891,13 +891,13 @@ void FlowPart::orientationPixmap( uint orientation, QPixmap & pm ) const
 		
 		int pos1 = nodeDirToPos( diamondNodePositioning[orientation][1] );
 		tick.translate( d[pos1].x(), d[pos1].y() );
-		p.drawLineSegments(tick);
-		maskPainter.drawLineSegments(tick);
+		p.drawLines(tick);
+		maskPainter.drawLines(tick);
 		//END Draw "true" output as a tick
 		
 		
 		//BEGIN Draw "false" output as a cross
-		Q3PointArray cross(4);
+		QPolygon cross(4);
 		cross[0] = QPoint( -2, -2 );
 		cross[1] = QPoint( 2, 2 );
 		cross[2] = QPoint( -2, 2 );
@@ -905,8 +905,8 @@ void FlowPart::orientationPixmap( uint orientation, QPixmap & pm ) const
 		
 		int pos2 = nodeDirToPos( diamondNodePositioning[orientation][2] );
 		cross.translate( d[pos2].x(), d[pos2].y() );
-		p.drawLineSegments(cross);
-		maskPainter.drawLineSegments(cross);
+		p.drawLines(cross);
+		maskPainter.drawLines(cross);
 		//END Draw "false" output as a cross
 	} else if ( m_stdInput || m_stdOutput ) {
 		p.drawRoundRect( int(0.3*size.width()), int(0.4*size.height()), int(0.4*size.width()), int(0.2*size.height()) );
@@ -945,7 +945,7 @@ void FlowPart::orientationPixmap( uint orientation, QPixmap & pm ) const
 		}
 		
 		if ( inPos != -1 ) {
-			Q3PointArray inArrow(6);
+			QPolygon inArrow(6);
 			for ( int i=0; i<6; ++i )
 			{
 				inArrow[i] = arrows[(inPos+2)%4][i];
@@ -956,7 +956,7 @@ void FlowPart::orientationPixmap( uint orientation, QPixmap & pm ) const
 		}
 		
 		if ( outPos != -1 ) {
-			Q3PointArray outArrow(6);
+			QPolygon outArrow(6);
 			for ( int i=0; i<6; ++i ) {
 				outArrow[i] = arrows[outPos][i];
 			}
