@@ -319,7 +319,7 @@ bool ICNDocument::deleteNodeGroup( Node *node )
 	{
 		if ( *it && (*it)->contains(node) ) {
 			delete *it;
-			m_nodeGroupList.remove(it);
+			m_nodeGroupList.erase(it);
 			return true;
 		}
 	}
@@ -381,18 +381,18 @@ void ICNDocument::getTranslatable(const ItemList &itemList, ConnectorList *fixed
 			const NodeInfoMap::iterator nlEnd = nodeMap.end();
 			for ( NodeInfoMap::iterator nlIt = nodeMap.begin(); nlIt != nlEnd; ++nlIt )
 			{
-				itemNodeList.append(nlIt.data().node);
+				itemNodeList.append(nlIt.value().node);
 			}
 			
 			ConnectorList conList = cnItem->connectorList();
-			conList.remove((Connector*)0);
+			conList.removeAll((Connector*)0);
 
 			const ConnectorList::iterator clEnd = conList.end();
 			for ( ConnectorList::iterator clit = conList.begin(); clit != clEnd; ++clit )
 			{
 				ConnectorMap::iterator cit = fixedConnectorMap.find(*clit);
 				if ( cit != fixedConnectorMap.end() ) {
-					cit.data()++;
+					cit.value()++;
 				} else	fixedConnectorMap[*clit] = 1;
 			}
 		}
@@ -414,7 +414,7 @@ void ICNDocument::getTranslatable(const ItemList &itemList, ConnectorList *fixed
 			NodeList externalNodeList = ng->externalNodeList();
 			const NodeList::iterator itemNodeListEnd = itemNodeList.end();
 			for ( NodeList::iterator inlIt = itemNodeList.begin(); inlIt != itemNodeListEnd; ++inlIt )
-				externalNodeList.remove(*inlIt);
+				externalNodeList.removeAll(*inlIt);
 			
 			if ( externalNodeList.isEmpty() )
 			{
@@ -442,7 +442,7 @@ void ICNDocument::getTranslatable(const ItemList &itemList, ConnectorList *fixed
 		Node *startNode = it.key()->endNode();
 		Node *endNode = it.key()->startNode();
 
-		if( (it.data() > 1)
+		if( (it.value() > 1)
 		 || (startNode && endNode && startNode->parentItem() == endNode->parentItem()) )
 		{
 			translatableConnectors->append( const_cast<Connector*>(it.key()) );
@@ -496,7 +496,7 @@ QPoint ICNDocument::gridSnap( const QPoint &pos )
 
 void ICNDocument::appendDeleteList( KtlQCanvasItem *qcanvasItem )
 {
-	if ( !qcanvasItem || m_itemDeleteList.findIndex(qcanvasItem) != -1 )
+	if ( !qcanvasItem || m_itemDeleteList.indexOf(qcanvasItem) != -1 )
 		return;
 	
 	m_itemDeleteList.append(qcanvasItem);
@@ -576,10 +576,10 @@ void ICNDocument::copy()
 	// Remove those connectors (and nodes) which are dangling on an orphan node
 	NCLMap::iterator nclEnd = nclMap.end();
 	for ( NCLMap::iterator it = nclMap.begin(); it != nclEnd; ++it ) {
-		if ( it.data().size() > 1 )
+		if ( it.value().size() > 1 )
 			nodeList.append(it.key());
-		else if ( it.data().size() > 0 )
-			connectorList.remove( it.data().at(0) );
+		else if ( it.value().size() > 0 )
+			connectorList.removeAll( it.value().at(0) );
 	}
 
 	data.addItems( m_selectList->items(false) );
@@ -816,7 +816,7 @@ ConnectorList ICNDocument::getCommonConnectors( const ItemList &list )
 			*it = 0;
 		}
 	}
-	connectorList.remove((Connector*)0);
+	connectorList.removeAll((Connector*)0);
 	return connectorList;
 }
 
@@ -836,7 +836,7 @@ NodeList ICNDocument::getCommonNodes( const ItemList &list )
 		const NodeInfoMap::iterator nodeMapEnd = nodeMap.end();
 		for(NodeInfoMap::iterator it = nodeMap.begin(); it != nodeMapEnd; ++it )
 		{
-			Node *node = it.data().node;
+			Node *node = it.value().node;
 			
 			if(!nodeList.contains(node) ) nodeList += node;
 
