@@ -31,7 +31,7 @@
 #include <kiconloader.h>
 #include <klocalizedstring.h>
 #include <kmessagebox.h>
-#include <k3popupmenu.h>
+// #include <k3popupmenu.h>
 //#include <kprinter.h>
 #include <kactionmenu.h>
 #include <kxmlguifactory.h>
@@ -41,13 +41,16 @@
 #include <qclipboard.h>
 #include <qcursor.h>
 #include <qimage.h>
-#include <q3paintdevicemetrics.h>
+#include <qmenu.h>
+// #include <q3paintdevicemetrics.h>
 #include <qpainter.h>
 #include <qpicture.h>
 #include <qregexp.h>
-#include <q3simplerichtext.h>
+// #include <q3simplerichtext.h> // 2018.08.13 - not needed
 #include <qtimer.h>
 #include <qprinter.h>
+#include <qtextedit.h>
+#include <qprintdialog.h>
 
 #include <cmath>
 #include <cassert>
@@ -88,7 +91,7 @@ ItemDocument::ItemDocument( const QString &caption, const char *name)
 #endif
 
 	m_pAlignmentAction = new KActionMenu( i18n("Alignment") /*, "format-justify-right" */ , this );
-    m_pAlignmentAction->setName("rightjust");
+    m_pAlignmentAction->setObjectName("rightjust");
     m_pAlignmentAction->setIcon( KIcon("format-justify-right") );
 	
 	slotUpdateConfiguration();
@@ -140,8 +143,9 @@ bool ItemDocument::registerItem(KtlQCanvasItem *qcanvasItem)
 }
 
 
-void ItemDocument::slotSetDrawAction( int drawAction )
+void ItemDocument::slotSetDrawAction(QAction *selected)
 {
+    int drawAction = selected->data().toInt();
 	m_cmManager->setDrawAction(drawAction);
 }
 
@@ -245,8 +249,12 @@ void ItemDocument::print()
 {
 	static QPrinter * printer = new QPrinter;
 	
-	if ( ! printer->setup( KTechlab::self() ) )
-		return;
+	//if ( ! printer->setup( KTechlab::self() ) )
+	//	return;
+    QPrintDialog printDialog(printer, KTechlab::self());
+    if ( ! printDialog.exec() ) {
+        return;
+    }
 	
 	// setup the printer.  with Qt, you always "print" to a
 	// QPainter.. whether the output medium is a pixmap, a screen,
@@ -255,13 +263,14 @@ void ItemDocument::print()
 	p.begin( printer );
 	
 	// we let our view do the actual printing
-	Q3PaintDeviceMetrics metrics( printer );
+	//Q3PaintDeviceMetrics metrics( printer ); // 2018.08.13 - replaced with method call
+    QRect pageRect = printer->pageRect();
 	
 	// Round to 16 so that we cut in the middle of squares
-	int w = metrics.width();
+	int w = pageRect.width();
 	w = (w & 0xFFFFFFF0) + ((w << 1) & 0x10);
 
-	int h = metrics.height();
+	int h = pageRect.height();
 	h = (h & 0xFFFFFFF0) + ((h << 1) & 0x10);
 
 	p.setClipping( true );
@@ -335,7 +344,7 @@ void ItemDocument::requestStateSave( int actionTicket )
 	// In Qt4 QStack is used and QStack inherits QVector, that should
 	// make it a bit more easy
 	int maxUndo = KTLConfig::maxUndo();
-	if ( maxUndo <= 0 || m_undoStack.count() < (unsigned)maxUndo )
+	if ( maxUndo <= 0 || m_undoStack.count() < maxUndo )
 		return;
 	IDDStack tempStack;
 	int pushed = 0;
@@ -382,6 +391,9 @@ bool ItemDocument::isRedoAvailable() const
 
 void ItemDocument::undo()
 {
+    if (m_undoStack.empty()) {
+        return;
+    }
 	ItemDocumentData *idd = m_undoStack.pop();
 	if (!idd) return;
 
@@ -396,6 +408,9 @@ void ItemDocument::undo()
 
 void ItemDocument::redo()
 {
+    if (m_redoStack.empty()) {
+        return;
+    }
 	ItemDocumentData *idd = m_redoStack.pop();
 	if (!idd) return;
 	
@@ -585,7 +600,7 @@ void ItemDocument::canvasRightClick( const QPoint &pos, KtlQCanvasItem* item )
 	KTechlab::self()->unplugActionList("orientation_actionlist");
 	fillContextMenu(pos);
 
-	Q3PopupMenu *pop = static_cast<Q3PopupMenu*>(KTechlab::self()->factory()->container("item_popup", KTechlab::self() ));
+	QMenu *pop = static_cast<QMenu*>(KTechlab::self()->factory()->container("item_popup", KTechlab::self() ));
 
 	if (!pop) return;
 
@@ -697,7 +712,8 @@ void ItemDocument::requestEvent( ItemDocumentEvent::type type )
 {
 	m_queuedEvents |= type;
 	m_pEventTimer->stop();
-	m_pEventTimer->start( 0, true );
+    m_pEventTimer->setSingleShot(true);
+	m_pEventTimer->start( 0 /*, true */ );
 }
 
 
@@ -727,7 +743,7 @@ void ItemDocument::resizeCanvasToItems()
 {
 	QRect bound = canvasBoundingRect();
 	
-	m_viewList.remove((View*)0);
+	m_viewList.removeAll((View*)0);
 	const ViewList::iterator end = m_viewList.end();
 	for ( ViewList::iterator it = m_viewList.begin(); it != end; ++it ) {
 		ItemView * iv = static_cast<ItemView*>((View*)*it);
@@ -748,7 +764,8 @@ void ItemDocument::resizeCanvasToItems()
 	bound.setLeft( bound.left() - (bound.left()%8) );
 	bound.setTop( bound.top() - (bound.top()%8) );
 	
-	m_pUpdateItemViewScrollbarsTimer->start( 10, true );
+    m_pUpdateItemViewScrollbarsTimer->setSingleShot(true);
+	m_pUpdateItemViewScrollbarsTimer->start( 10 /*, true */ );
 	
 	bool changedSize = canvas()->rect() != bound;
 	if ( changedSize ) {
@@ -770,9 +787,9 @@ void ItemDocument::updateItemViewScrollbars()
 	{
 		ItemView * itemView = static_cast<ItemView*>((View*)*it);
 		CVBEditor * cvbEditor = itemView->cvbEditor();
-		
-		cvbEditor->setVScrollBarMode( ((h*itemView->zoomLevel()) > cvbEditor->visibleHeight()) ? Q3ScrollView::AlwaysOn : Q3ScrollView::AlwaysOff );
-		cvbEditor->setHScrollBarMode( ((w*itemView->zoomLevel()) > cvbEditor->visibleWidth()) ? Q3ScrollView::AlwaysOn : Q3ScrollView::AlwaysOff );
+		// TODO QT3
+		cvbEditor->setVScrollBarMode( ((h*itemView->zoomLevel()) > cvbEditor->visibleHeight()) ? KtlQ3ScrollView::AlwaysOn : KtlQ3ScrollView::AlwaysOff );
+		cvbEditor->setHScrollBarMode( ((w*itemView->zoomLevel()) > cvbEditor->visibleWidth()) ? KtlQ3ScrollView::AlwaysOn : KtlQ3ScrollView::AlwaysOff );
 	}
 }
 
@@ -842,7 +859,8 @@ void ItemDocument::exportToImage()
 
 	cropMessage = i18n("Crop image");
 	
-	QCheckBox *cropCheck = new QCheckBox( cropMessage, KTechlab::self(), "cropCheck" );
+	QCheckBox *cropCheck = new QCheckBox( cropMessage, KTechlab::self() /*, "cropCheck" */ );
+    cropCheck->setObjectName( "cropCheck" );
 	cropCheck->setChecked(true); // yes by default?
 	
 	// we need an object so we can retrieve which image type was selected by the user
@@ -867,9 +885,7 @@ void ItemDocument::exportToImage()
 		int query = KMessageBox::warningYesNo(
             KTechlab::self(),
             i18n( "A file named \"%1\" already exists. " "Are you sure you want to overwrite it?", url.fileName() ),
-            i18n( "Overwrite File?" ),
-            //i18n( "Overwrite" ),
-            KStandardGuiItem::cancel() );
+            i18n( "Overwrite File?" ));
 
 		if ( query == KMessageBox::No ) return;
 	}
@@ -885,7 +901,7 @@ void ItemDocument::exportToImage()
 	QRect cropArea;
 	QPaintDevice *outputImage;
 	QString filter = exportDialog.currentFilter();
-	filter = filter.lower(); // gently soften the appearance of the letters.
+	filter = filter.toLower(); // gently soften the appearance of the letters.
 	
 	// did have a switch here but seems you can't use that on strings
 	if ( filter == "*.png") 	type = "PNG";
@@ -925,18 +941,20 @@ void ItemDocument::exportToImage()
 		return;
 	}
 	
-	//QPainter p(outputImage); // 2016.05.03 - explicitly initialize painter
-	QPainter p;
-    const bool isBeginSuccess = p.begin(outputImage);
-    if (!isBeginSuccess) {
-        qWarning() << Q_FUNC_INFO << " painter not active";
-    }
-	
-	m_canvas->setBackgroundPixmap(QPixmap());
-	m_canvas->drawArea( saveArea, &p );
-	updateBackground();
-	
-	p.end();
+//2018.05.05 - extract to a method
+// 	//QPainter p(outputImage); // 2016.05.03 - explicitly initialize painter
+// 	QPainter p;
+//     const bool isBeginSuccess = p.begin(outputImage);
+//     if (!isBeginSuccess) {
+//         qWarning() << Q_FUNC_INFO << " painter not active";
+//     }
+//
+// 	m_canvas->setBackgroundPixmap(QPixmap());
+// 	m_canvas->drawArea( saveArea, &p );
+// 	updateBackground();
+//
+// 	p.end();
+    exportToImageDraw(saveArea, *outputImage);
 
 	bool saveResult;
 	
@@ -947,9 +965,16 @@ void ItemDocument::exportToImage()
 		if( type == "SVG" )
 			saveResult = dynamic_cast<QPicture*>(outputImage)->save( url.path(), type.toLatin1().data());
 		else {
-			QImage img = dynamic_cast<QPixmap*>(outputImage)->convertToImage();
-			img = img.copy(cropArea);
-			saveResult = img.save(url.path(),type.toLatin1().data());
+			QImage img = dynamic_cast<QPixmap*>(outputImage)->toImage();
+            if ( saveArea.x() < 0 ) {
+                cropArea.translate( - saveArea.x(), 0 );
+            }
+            if ( saveArea.y() < 0 ) {
+                cropArea.translate( 0, - saveArea.y() );
+            }
+            qDebug() << Q_FUNC_INFO << " cropArea " << cropArea;
+			QImage imgCropped = img.copy(cropArea);
+			saveResult = imgCropped.save(url.path(),type.toLatin1().data());
 		}
 	} else {
 		if ( type=="SVG" )
@@ -968,6 +993,25 @@ void ItemDocument::exportToImage()
 	delete outputImage;
 }
 
+void ItemDocument::exportToImageDraw( const QRect &saveArea, QPaintDevice &pDev) {
+    qDebug() << Q_FUNC_INFO << " saveArea " << saveArea;
+    //QPainter p(outputImage); // 2016.05.03 - explicitly initialize painter
+    QPainter p;
+    const bool isBeginSuccess = p.begin(&pDev);
+    if (!isBeginSuccess) {
+        qWarning() << Q_FUNC_INFO << " painter not active";
+    }
+
+    QTransform transf;
+    transf.translate( -saveArea.x(), -saveArea.y());
+    p.setTransform(transf);
+
+    m_canvas->setBackgroundPixmap(QPixmap());
+    m_canvas->drawArea( saveArea, &p );
+    updateBackground();
+
+    p.end();
+}
 
 void ItemDocument::setSVGExport( bool svgExport )
 {
@@ -995,13 +1039,13 @@ void ItemDocument::raiseZ( const ItemList & itemList )
 	IntItemMap::iterator previous = m_zOrder.end();
 	IntItemMap::iterator it = --m_zOrder.end();
 	do {
-		Item * previousData = (previous == m_zOrder.end()) ? 0l : previous.data();
-		Item * currentData = it.data();
+		Item * previousData = (previous == m_zOrder.end()) ? 0l : previous.value();
+		Item * currentData = it.value();
 		
 		if ( currentData && previousData && itemList.contains(currentData) && !itemList.contains(previousData) )
 		{
-			previous.data() = currentData;
-			it.data() = previousData;
+			previous.value() = currentData;
+			it.value() = previousData;
 		}
 		
 		previous = it;
@@ -1027,13 +1071,13 @@ void ItemDocument::lowerZ( const ItemList &itemList )
 	IntItemMap::iterator end = m_zOrder.end();
 	for ( IntItemMap::iterator it = m_zOrder.begin(); it != end; ++it )
 	{
-		Item * previousData = previous.data();
-		Item * currentData = it.data();
+		Item * previousData = previous.value();
+		Item * currentData = it.value();
 		
 		if ( currentData && previousData && itemList.contains(currentData) && !itemList.contains(previousData) )
 		{
-			previous.data() = currentData;
-			it.data() = previousData;
+			previous.value() = currentData;
+			it.value() = previousData;
 		}
 		
 		previous = it;
@@ -1059,7 +1103,7 @@ void ItemDocument::slotUpdateZOrdering()
 	IntItemMap::iterator zEnd = m_zOrder.end();
 	for ( IntItemMap::iterator it = m_zOrder.begin(); it != zEnd; ++it )
 	{	
-		Item * item = it.data();
+		Item * item = it.value();
 		if (!item) continue;
 		
 		toAdd.remove( item->id() );
@@ -1082,7 +1126,7 @@ void ItemDocument::slotUpdateZOrdering()
 	
 	zEnd = m_zOrder.end();
 	for ( IntItemMap::iterator it = m_zOrder.begin(); it != zEnd; ++it )
-		it.data()->updateZ( it.key() );
+		it.value()->updateZ( it.key() );
 }
 
 
@@ -1103,7 +1147,7 @@ ItemList ItemDocument::itemList( ) const
 	
 	ItemMap::const_iterator end = m_itemList.end();
 	for ( ItemMap::const_iterator it = m_itemList.begin(); it != end; ++it )
-		l << it.data();
+		l << it.value();
 
 	return l;
 }
@@ -1210,7 +1254,7 @@ void CanvasTip::display( const QPoint &pos )
 
 QString CanvasTip::displayText( unsigned num ) const
 {
-	if ( m_v.size() <= num )
+	if ( m_v.size() <= (int)num )
 		return QString::null;
 	
 	return QString("%1%2V  %3%4A")
@@ -1273,9 +1317,12 @@ void Canvas::setMessage( const QString & message )
 {
 	m_message = message;
 	
-	if ( message.isEmpty() )
+	if ( message.isEmpty() ) {
 		m_pMessageTimeout->stop();
-	else	m_pMessageTimeout->start( 2000, true );
+    } else {
+        m_pMessageTimeout->setSingleShot(true);
+        m_pMessageTimeout->start( 2000 /*, true */ );
+    }
 	
 	setAllChanged();
 }
@@ -1345,23 +1392,38 @@ void Canvas::drawForeground ( QPainter &p, const QRect & clip )
 	
 	if ( !firstView ) return;
 	
-	Q3SimpleRichText * t = new Q3SimpleRichText( m_message, QApplication::font() );
+// 	Q3SimpleRichText * t = new Q3SimpleRichText( m_message, QApplication::font() );
+    QTextEdit * t = new QTextEdit( m_message );
 	
+    {
+        QFont tf = t->document()->defaultFont();
+        QFontMetrics tfm(tf);
+        QSize textSize = tfm.size(0, m_message);
+
+        t->resize( textSize );
+    }
+
 	int w = t->width();
 	int h = t->height();
 	int x = rect().left() + 15;
 	int y = rect().top() + 15;
 	int b = 10; // text padding
 	
-	if ( w+2*b >= minSize.width() || h+2*b >= minSize.height() )
-	{
-		delete t;
-		return;
-	}
+// 	if ( w+2*b >= minSize.width() || h+2*b >= minSize.height() )
+// 	{
+//         qWarning() << Q_FUNC_INFO << "size not good w=" << w << " h=" << h << "b=" << b << " minSize=" << minSize;
+// 		delete t;
+// 		return;
+// 	}
 	
-	p.setBrush( firstView->colorGroup().background() );
+    //p.setBrush( firstView->colorGroup().background() ); // 2018.12.02
+	p.setBrush( firstView->palette().window() );
 	p.drawRoundRect( x, y, w+2*b, h+2*b, (8*200)/(w+2*b), (8*200)/(h+2*b) );
-	t->draw( &p, x+b, y+b, QRect(), firstView->colorGroup() );
+// 	t->draw( &p, x+b, y+b, QRect(), firstView->colorGroup() );
+    t->resize(w+2*b, h+2*b);
+    t->viewport()->setAutoFillBackground( false );
+    t->setFrameStyle(QFrame::NoFrame);
+    t->render( &p, QPoint( x, y ) , QRegion(), QWidget::DrawChildren );
 	delete t;
 }
 
