@@ -321,7 +321,7 @@ void ItemLibrary::addMechanics()
 
 void ItemLibrary::addLibraryItem( LibraryItem *item )
 {
-	m_items.append(item);
+	m_items.prepend(item);
 }
 
 
@@ -388,7 +388,7 @@ QImage ItemLibrary::componentImage( Component * component, const uint maxSize )
 	component->setAngleDegrees( 0 );
 	component->setFlipped( false );
 	
-	QRect bound = component->boundingRect().normalize();
+	QRect bound = component->boundingRect().normalized();
 	bound.setLeft( bound.left()-8 );
 	bound.setRight( bound.right()+8 );
 	bound.setTop( bound.top()-8 );
@@ -464,14 +464,14 @@ QImage ItemLibrary::componentImage( Component * component, const uint maxSize )
 	maskPainter.setPen( Qt::color1 );
 	maskPainter.setBrush( Qt::color1 );
 	
-	QWMatrix transMatrix; // Matrix to apply to the image
+	QMatrix transMatrix; // Matrix to apply to the image
 	
 	
 	NodeInfoMap nodes = component->nodeMap();
 	const NodeInfoMap::iterator nodesEnd = nodes.end();
 	for ( NodeInfoMap::iterator it = nodes.begin(); it != nodesEnd; ++it )
 	{
-		Node *node = it.data().node;
+		Node *node = it.value().node;
 		const bool sel = node->isSelected();
 		if (sel)
 			node->setSelected(false);
@@ -501,8 +501,8 @@ QImage ItemLibrary::componentImage( Component * component, const uint maxSize )
 	const TextMap::iterator textEnd = text.end();
 	for ( TextMap::iterator it = text.begin(); it != textEnd; ++it )
 	{
-		it.data()->drawShape(p);
-		it.data()->drawShape(maskPainter);
+		it.value()->drawShape(p);
+		it.value()->drawShape(maskPainter);
 	}
 		
 // 	maskPainter.setPen( Qt::color1 );
@@ -515,8 +515,9 @@ QImage ItemLibrary::componentImage( Component * component, const uint maxSize )
 	pm.setMask(mask); // pm needs not to have active painters on it
 		
 	// Now, rotate the image so that it's the right way up, and scale it to size
-	QImage im = pm.convertToImage();
-	im = im.smoothScale( 50, 50, Qt::ScaleMin );
+	QImage im = pm.toImage();
+	//im = im.smoothScale( 50, 50, Qt::ScaleMin ); //2018.12.01
+    im = im.scaled( QSize( 50, 50 ), Qt::KeepAspectRatio, Qt::SmoothTransformation );
 	
 	if (cache)
 		m_imageMap[component->type()] = im;
@@ -559,7 +560,7 @@ bool ItemLibrary::saveDescriptions( const QString & language )
 	for ( QStringMap::iterator descIt = m_itemDescriptions[ language ].begin(); descIt != end; ++descIt )
 	{
 		stream << QString("<!-- item: %1 -->\n").arg( descIt.key() );
-		stream << descIt.data() << endl;
+		stream << descIt.value() << endl;
 	}
 	
 	file.close();
@@ -701,12 +702,12 @@ void ItemLibrary::loadItemDescriptions()
 			{
 				// Save the previous description
 				if ( !type.isEmpty() )
-					m_itemDescriptions[ *it ][ type ] = description.stripWhiteSpace();
+					m_itemDescriptions[ *it ][ type ] = description.trimmed();
 			
 				line.remove( "<!-- item: " );
 				line.remove( " -->" );
 				
-				type = line.stripWhiteSpace();
+				type = line.trimmed();
 				if ( type.startsWith("/") )
 				{
 					// Possibly change e.g. "/ec/capacitor" to "ec/capacitor"
@@ -719,7 +720,7 @@ void ItemLibrary::loadItemDescriptions()
 	
 		// Save the previous description
 		if ( !type.isEmpty() )
-			m_itemDescriptions[ *it ][ type ] = description.stripWhiteSpace();
+			m_itemDescriptions[ *it ][ type ] = description.trimmed();
 	
 		file.close();
 	}
