@@ -28,14 +28,14 @@
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <klocalizedstring.h>
-#include <k3popupmenu.h>
+// #include <k3popupmenu.h>
 #include <ktoolbarpopupaction.h>
 #include <kactioncollection.h>
 
 #include <qapplication.h>
 #include <qcursor.h>
 #include <qtimer.h>
-#include <qwmatrix.h>
+#include <qmatrix.h>
 
 #include <cmath>
 #include <kmenu.h>
@@ -59,7 +59,7 @@ ItemView::ItemView( ItemDocument * itemDocument, ViewContainer *viewContainer, u
 	//pAccel->insert( "Cancel", i18n("Cancel"), i18n("Cancel the current operation"), Qt::Key_Escape, itemDocument, SLOT(cancelCurrentOperation()) );
 	//pAccel->readSettings(); // TODO what does this do?
     KAction *pAccel = new KAction( KIcon("process-stop"), i18n("Cancel"), ac);
-    pAccel->setName("cancelCurrentOperation");
+    pAccel->setObjectName("cancelCurrentOperation");
     pAccel->setShortcut(Qt::Key_Escape);
     connect(pAccel, SIGNAL(triggered(bool)), itemDocument, SLOT(cancelCurrentOperation()));
     ac->addAction("cancelCurrentOperation", pAccel);
@@ -67,7 +67,7 @@ ItemView::ItemView( ItemDocument * itemDocument, ViewContainer *viewContainer, u
     {
 	//new KAction( i18n("Delete"), "edit-delete", Qt::Key_Delete, itemDocument, SLOT(deleteSelection()), ac, "edit_delete" );
         KAction *action = new KAction( KIcon("edit-delete"), i18n("Delete"), ac);
-        action->setName("edit_delete");
+        action->setObjectName("edit_delete");
         action->setShortcut( Qt::Key_Delete );
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(deleteSelection()));
         ac->addAction("edit_delete", action);
@@ -75,7 +75,7 @@ ItemView::ItemView( ItemDocument * itemDocument, ViewContainer *viewContainer, u
     {
 	//new KAction( i18n("Export as Image..."), 0, 0, itemDocument, SLOT(exportToImage()), ac, "file_export_image");
         KAction *action = new KAction( KIcon("document-export"), i18n("Export as Image..."), ac);
-        action->setName("file_export_image");
+        action->setObjectName("file_export_image");
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(exportToImage()));
         ac->addAction("file_export_image", action);
     }
@@ -84,28 +84,28 @@ ItemView::ItemView( ItemDocument * itemDocument, ViewContainer *viewContainer, u
 	{
 	//new KAction( i18n("Align Horizontally"), 0, 0, itemDocument, SLOT(alignHorizontally()), ac, "align_horizontally" );
         KAction *action = new KAction( KIcon("align-horizontal-center"), i18n("Align Horizontally"), ac);
-        action->setName("align_horizontally");
+        action->setObjectName("align_horizontally");
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(alignHorizontally()));
         ac->addAction("align_horizontally", action);
     }
     {
 	//new KAction( i18n("Align Vertically"), 0, 0, itemDocument, SLOT(alignVertically()), ac, "align_vertically" );
         KAction *action = new KAction( KIcon("align-vertical-center"), i18n("Align Vertically"), ac);
-        action->setName("align_vertically");
+        action->setObjectName("align_vertically");
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(alignVertically()));
         ac->addAction("align_vertically", action);
     }
     {
 	//new KAction( i18n("Distribute Horizontally"), 0, 0, itemDocument, SLOT(distributeHorizontally()), ac, "distribute_horizontally" );
         KAction *action = new KAction( KIcon("distribute-horizontal-x"), i18n("Distribute Horizontally"), ac);
-        action->setName("distribute_horizontally");
+        action->setObjectName("distribute_horizontally");
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(distributeHorizontally()));
         ac->addAction("distribute_horizontally", action);
     }
     {
 	//new KAction( i18n("Distribute Vertically"), 0, 0, itemDocument, SLOT(distributeVertically()), ac, "distribute_vertically" );
         KAction *action = new KAction( KIcon("distribute-vertical-y"), i18n("Distribute Vertically"), ac);
-        action->setName("distribute_vertically");
+        action->setObjectName("distribute_vertically");
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(distributeVertically()));
         ac->addAction("distribute_vertically", action);
     }
@@ -115,20 +115,20 @@ ItemView::ItemView( ItemDocument * itemDocument, ViewContainer *viewContainer, u
 	//BEGIN Draw actions
 	//KToolBarPopupAction * pa = new KToolBarPopupAction( i18n("Draw"), "paintbrush", 0, 0, 0, ac, "edit_draw" );
 	KToolBarPopupAction * pa = new KToolBarPopupAction( KIcon("draw-brush"), i18n("Draw"), ac);
-    pa->setName("edit_draw");
+    pa->setObjectName("edit_draw");
 	pa->setDelayed(false);
     ac->addAction("edit_draw", pa);
 	
 	QMenu * m = pa->menu();
 	m->setTitle( i18n("Draw") );
 	
-	m->insertItem( KIcon( "draw-text" ), i18n("Text"),		DrawPart::da_text );
-	m->insertItem( KIcon( "draw-line" ), i18n("Line"),		DrawPart::da_line );
-	m->insertItem( KIcon( "draw-arrow"  ), i18n("Arrow"),		DrawPart::da_arrow );
-	m->insertItem( KIcon( "draw-ellipse" ), i18n("Ellipse"),	DrawPart::da_ellipse );
-	m->insertItem( KIcon( "draw-rectangle" ), i18n("Rectangle"),	DrawPart::da_rectangle );
-	m->insertItem( KIcon( "insert-image" ), i18n("Image"),		DrawPart::da_image );
-	connect( m, SIGNAL(activated(int)), itemDocument, SLOT(slotSetDrawAction(int)) );
+	m->addAction( KIcon( "draw-text" ), i18n("Text"))->setData(DrawPart::da_text );
+	m->addAction( KIcon( "draw-line" ), i18n("Line"))->setData(DrawPart::da_line );
+	m->addAction( KIcon( "draw-arrow"  ), i18n("Arrow"))->setData(DrawPart::da_arrow );
+	m->addAction( KIcon( "draw-ellipse" ), i18n("Ellipse"))->setData(DrawPart::da_ellipse );
+	m->addAction( KIcon( "draw-rectangle" ), i18n("Rectangle"))->setData(DrawPart::da_rectangle );
+	m->addAction( KIcon( "insert-image" ), i18n("Image"))->setData(DrawPart::da_image );
+	connect( m, SIGNAL(triggered(QAction*)), itemDocument, SLOT(slotSetDrawAction(QAction*)) );
 	//END Draw actions
 	
 	
@@ -136,7 +136,7 @@ ItemView::ItemView( ItemDocument * itemDocument, ViewContainer *viewContainer, u
     {
 	//new KAction( i18n("Raise Selection"), "object-order-raise", Qt::Key_PageUp,   itemDocument, SLOT(raiseZ()), ac, "edit_raise" );
         KAction * action = new KAction( KIcon("object-order-raise"), i18n("Raise Selection"), ac);
-        action->setName("edit_raise");
+        action->setObjectName("edit_raise");
         action->setShortcut(Qt::Key_PageUp);
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(raiseZ()));
         ac->addAction("edit_raise", action);
@@ -144,7 +144,7 @@ ItemView::ItemView( ItemDocument * itemDocument, ViewContainer *viewContainer, u
     {
 	//new KAction( i18n("Lower Selection"), "object-order-lower", Qt::Key_PageDown, itemDocument, SLOT(lowerZ()), ac, "edit_lower" );
         KAction *action = new KAction( KIcon("object-order-lower"), i18n("Lower Selection"), ac);
-        action->setName("edit_lower");
+        action->setObjectName("edit_lower");
         action->setShortcut(Qt::Key_PageDown);
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(lowerZ()));
         ac->addAction("edit_lower", action);
@@ -155,7 +155,7 @@ ItemView::ItemView( ItemDocument * itemDocument, ViewContainer *viewContainer, u
 	{
 	//KAction * na = new KAction( "", 0, 0, 0, 0, ac, "null_action" );
     KAction * na = new KAction( "", ac);
-    na->setName("null_action");
+    na->setObjectName("null_action");
 	na->setEnabled(false);
     }
 	
@@ -292,7 +292,7 @@ void ItemView::zoomOut()
 void ItemView::actualSize()
 {
 	m_zoomLevel = 1.0;
-	QWMatrix m( m_zoomLevel, 0.0, 0.0, m_zoomLevel, 1.0, 1.0 );
+	QMatrix m( m_zoomLevel, 0.0, 0.0, m_zoomLevel, 1.0, 1.0 );
 	m_CVBEditor->setWorldMatrix(m);
 	
 	p_itemDocument->requestEvent( ItemDocument::ItemDocumentEvent::ResizeCanvasToItems );
@@ -468,7 +468,7 @@ void ItemView::dragEnterEvent( QDragEnterEvent *event )
 	startUpdatingStatus();
 	
 	if ( KUrl::List::canDecode( event->mimeData() ) ) {
-		event->accept(true);
+		event->setAccepted(true);
 		// Then it is URLs that we can decode later :)
 		return;
 	}
@@ -552,11 +552,17 @@ void ItemView::leaveEvent( QEvent * e )
 		p_itemDocument->m_canvasTip->setVisible(false);
 }
 
+void ItemView::requestDocumentResizeToCanvasItems() {
+    p_itemDocument->requestEvent( ItemDocument::ItemDocumentEvent::ResizeCanvasToItems );
+}
 
 void ItemView::slotUpdateConfiguration()
 {
 // 	m_CVBEditor->setEraseColor( KTLConfig::bgColor() );
-	m_CVBEditor->setEraseColor( Qt::white );
+	//m_CVBEditor->setEraseColor( Qt::white ); // 2018.12.02
+    QPalette pe;
+    pe.setColor(m_CVBEditor->backgroundRole(), Qt::white );
+    m_CVBEditor->setPalette(pe);
 	
 	if ( m_pUpdateStatusTmr->isActive() )
 		startUpdatingStatus();
@@ -654,8 +660,9 @@ void ItemView::updateStatus()
 
 //BEGIN class CVBEditor
 CVBEditor::CVBEditor( Canvas *canvas, ItemView *itemView, const char *name )
-	: KtlQCanvasView( canvas, itemView, name, Qt::WNoAutoErase | Qt::WStaticContents )
+	: KtlQCanvasView( canvas, itemView, name /*,Qt::WNoAutoErase | Qt::WA_StaticContents */ )
 {
+    setAttribute(Qt::WA_StaticContents);
 	m_pCanvas = canvas;
 	b_ignoreEvents = false;
 	b_passEventsToView = true;
@@ -666,10 +673,20 @@ CVBEditor::CVBEditor( Canvas *canvas, ItemView *itemView, const char *name )
 	setAcceptDrops(true);
 	setFrameShape(NoFrame);
 // 	setEraseColor( KTLConfig::bgColor() );
-	setEraseColor( Qt::white );
-	setPaletteBackgroundColor( Qt::white );
-	viewport()->setEraseColor( Qt::white );
-	viewport()->setPaletteBackgroundColor( Qt::white );
+	//setEraseColor( Qt::white );
+	//setPaletteBackgroundColor( Qt::white );
+    {
+        QPalette p;
+        p.setColor(backgroundRole(), Qt::white);
+        setPalette(p);
+    }
+	//viewport()->setEraseColor( Qt::white );
+	//viewport()->setPaletteBackgroundColor( Qt::white ); // 2018.12.02
+    {
+        QPalette pv;
+        pv.setColor(viewport()->backgroundRole(), Qt::white );
+        viewport()->setPalette(pv);
+    }
 	
 	connect( canvas, SIGNAL(resized( const QRect&, const QRect& )), this, SLOT(canvasResized( const QRect&, const QRect& )) );
 }
@@ -693,9 +710,9 @@ void CVBEditor::updateWorldMatrix()
 {
 	double z = p_itemView->zoomLevel();
 	QRect r = m_pCanvas->rect();
-// 	QWMatrix m( z, 0.0, 0.0, z, -r.left(), -r.top() );
-// 	QWMatrix m( z, 0.0, 0.0, z, 0.0, 0.0 );
-	QWMatrix m;
+// 	QMatrix m( z, 0.0, 0.0, z, -r.left(), -r.top() );
+// 	QMatrix m( z, 0.0, 0.0, z, 0.0, 0.0 );
+	QMatrix m;
 	m.scale( z, z );
 	m.translate( -r.left(), -r.top() );
 	setWorldMatrix( m );
@@ -705,7 +722,9 @@ void CVBEditor::updateWorldMatrix()
 void CVBEditor::contentsWheelEvent( QWheelEvent * e )
 {
 	QWheelEvent ce( viewport()->mapFromGlobal( e->globalPos() ),
-			e->globalPos(), e->delta(), e->state());
+			e->globalPos(), e->delta(),
+            //e->state()
+            e->buttons(), e->modifiers());
 	
 	if ( e->orientation() == Qt::Horizontal && horizontalScrollBar() )
 		QApplication::sendEvent( horizontalScrollBar(), e);
@@ -791,7 +810,9 @@ bool CVBEditor::event( QEvent * e )
 void CVBEditor::viewportResizeEvent( QResizeEvent * e )
 {
 	KtlQCanvasView::viewportResizeEvent(e);
-	p_itemView->p_itemDocument->requestEvent( ItemDocument::ItemDocumentEvent::ResizeCanvasToItems );
+    // 2018.09.26 - move to explicit method
+	//p_itemView->p_itemDocument->requestEvent( ItemDocument::ItemDocumentEvent::ResizeCanvasToItems );
+    p_itemView->requestDocumentResizeToCanvasItems();
 }
 //END class CVBEditor
 
