@@ -22,6 +22,7 @@
 #include "textview.h"
 #include "variablelabel.h"
 #include "viewiface.h"
+#include "ktlfindqobjectchild.h"
 
 //#include <ktexteditor/editinterface.h> // ?
 #include <ktexteditor/texthintinterface.h>
@@ -30,7 +31,7 @@
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <klocalizedstring.h>
-#include <k3popupmenu.h>
+// #include <k3popupmenu.h>
 #include <kstandarddirs.h>
 #include <ktoolbarpopupaction.h>
 #include <kmenu.h>
@@ -58,27 +59,29 @@ TextView::TextView( TextDocument * textDocument, ViewContainer *viewContainer, u
 	//BEGIN Convert To * Actions
 	//KToolBarPopupAction * pa = new KToolBarPopupAction( i18n("Convert to"), "fork", 0, 0, 0, ac, "program_convert" );
     KToolBarPopupAction * pa = new KToolBarPopupAction( KIcon("fork"), i18n("Convert To"), ac);
-    pa->setName("program_convert");
+    pa->setObjectName("program_convert");
 	pa->setDelayed(false);
     ac->addAction("program_convert", pa);
 	
 	QMenu * m = pa->menu();
 
     m->setTitle( i18n("Convert To") );
-	m->insertItem( KIcon( "convert_to_microbe" ), i18n("Microbe"), TextDocument::MicrobeOutput );
-	m->insertItem( KIcon( "convert_to_assembly" ), i18n("Assembly"), TextDocument::AssemblyOutput );
-	m->insertItem( KIcon( "convert_to_hex" ), i18n("Hex"), TextDocument::HexOutput );
-	m->insertItem( KIcon( "convert_to_pic" ), i18n("PIC (upload)"), TextDocument::PICOutput );
-	connect( m, SIGNAL(activated(int)), textDocument, SLOT(slotConvertTo(int)) );
+    QAction *actToMicrobe = m->addAction( KIcon( "convert_to_microbe" ), i18n("Microbe"));
+    actToMicrobe->setData( TextDocument::MicrobeOutput );
+	m->addAction( KIcon( "convert_to_assembly" ), i18n("Assembly"))->setData( TextDocument::AssemblyOutput );
+	m->addAction( KIcon( "convert_to_hex" ), i18n("Hex"))->setData( TextDocument::HexOutput );
+	m->addAction( KIcon( "convert_to_pic" ), i18n("PIC (upload)"))->setData( TextDocument::PICOutput );
+	connect( m, SIGNAL(triggered(QAction*)), textDocument, SLOT(slotConvertTo(QAction*)) );
 	
-	m->setItemEnabled( TextDocument::MicrobeOutput, false );
+	//m->setItemEnabled( TextDocument::MicrobeOutput, false ); // 2018.12.02
+    actToMicrobe->setEnabled(false);
     ac->addAction("program_convert", pa);
 	//END Convert To * Actions
 	
     {
 	//new KAction( i18n("Format Assembly Code"), "", Qt::Key_F12, textDocument, SLOT(formatAssembly()), ac, "format_asm" );
         KAction *action = new KAction( KIcon(""), i18n("Format Assembly Code"), ac);
-        action->setName("format_asm");
+        action->setObjectName("format_asm");
         action->setShortcut(Qt::Key_F12);
         connect(action, SIGNAL(triggered(bool)), textDocument, SLOT(formatAssembly()));
         ac->addAction("format_asm", action);
@@ -90,35 +93,35 @@ TextView::TextView( TextDocument * textDocument, ViewContainer *viewContainer, u
 	{
 	//new KAction( i18n("Set &Breakpoint"), 0, 0, this, SLOT(toggleBreakpoint()), ac, "debug_toggle_breakpoint" );
         KAction *action = new KAction( KIcon(""), i18n("Set &Breakpoint"), ac);
-        action->setName("debug_toggle_breakpoint");
+        action->setObjectName("debug_toggle_breakpoint");
         connect(action, SIGNAL(triggered(bool)), this, SLOT(toggleBreakpoint()));
         ac->addAction("debug_toggle_breakpoint", action);
     }
     {
 	//new KAction( i18n("Run"), "debug-run", 0, textDocument, SLOT(debugRun()), ac, "debug_run" );
         KAction *action = new KAction( KIcon("debug-run"), i18n("Run"), ac);
-        action->setName("debug_run");
+        action->setObjectName("debug_run");
         connect(action, SIGNAL(triggered(bool)), textDocument, SLOT(debugRun()));
         ac->addAction("debug_run", action);
     }
     {
 	//new KAction( i18n("Interrupt"), "media-playback-pause", 0, textDocument, SLOT(debugInterrupt()), ac, "debug_interrupt" );
         KAction *action = new KAction( KIcon("media-playback-pause"), i18n("Interrupt"), ac);
-        action->setName("debug_interrupt");
+        action->setObjectName("debug_interrupt");
         connect(action, SIGNAL(triggered(bool)), textDocument, SLOT(debugInterrupt()));
         ac->addAction("debug_interrupt", action);
     }
     {
 	//new KAction( i18n("Stop"), "process-stop", 0, textDocument, SLOT(debugStop()), ac, "debug_stop" );
         KAction *action = new KAction( KIcon("process-stop"), i18n("Stop"), ac);
-        action->setName("debug_stop");
+        action->setObjectName("debug_stop");
         connect(action, SIGNAL(triggered(bool)), textDocument, SLOT(debugStop()));
         ac->addAction("debug_stop", action);
     }
     {
 	//new KAction( i18n("Step"), "debug-step-instruction", Qt::CTRL|Qt::ALT|Qt::Key_Right, textDocument, SLOT(debugStep()), ac, "debug_step" );
         KAction *action = new KAction( KIcon("debug-step-instruction"), i18n("Step"), ac);
-        action->setName("debug_step");
+        action->setObjectName("debug_step");
         action->setShortcut(Qt::CTRL|Qt::ALT|Qt::Key_Right);
         connect(action, SIGNAL(triggered(bool)), textDocument, SLOT(debugStep()));
         ac->addAction("debug_step", action);
@@ -126,14 +129,14 @@ TextView::TextView( TextDocument * textDocument, ViewContainer *viewContainer, u
     {
 	//new KAction( i18n("Step Over"), "debug-step-over", 0, textDocument, SLOT(debugStepOver()), ac, "debug_step_over" );
         KAction *action = new KAction( KIcon("debug-step-over"), i18n("Step Over"), ac);
-        action->setName("debug_step_over");
+        action->setObjectName("debug_step_over");
         connect(action, SIGNAL(triggered(bool)), textDocument, SLOT(debugStepOver()));
         ac->addAction("debug_step_over", action);
     }
     {
 	//new KAction( i18n("Step Out"), "debug-step-out", 0, textDocument, SLOT(debugStepOut()), ac, "debug_step_out" );
         KAction *action = new KAction( KIcon("debug-step-out"), i18n("Step Out"), ac);
-        action->setName("debug_step_out");
+        action->setObjectName("debug_step_out");
         connect(action, SIGNAL(triggered(bool)), textDocument, SLOT(debugStepOut()));
         ac->addAction("debug_step_out", action);
     }
@@ -153,9 +156,10 @@ TextView::TextView( TextDocument * textDocument, ViewContainer *viewContainer, u
 	m_statusBar->insertItem( "", ViewStatusBar::LineCol );
 	
 	//m_view->installPopup( static_cast<Q3PopupMenu*>( KTechlab::self()->factory()->container( "ktexteditor_popup", KTechlab::self() ) ) );
-    m_view->setContextMenu( static_cast<Q3PopupMenu*>( KTechlab::self()->factory()->container( "ktexteditor_popup", KTechlab::self() ) ) );
+    m_view->setContextMenu( static_cast<QMenu*>( KTechlab::self()->factory()->container( "ktexteditor_popup", KTechlab::self() ) ) );
 	
-	QWidget * internalView = static_cast<QWidget*>( m_view->child( 0, "KateViewInternal" ) );
+	//QWidget * internalView = static_cast<QWidget*>( m_view->child( 0, "KateViewInternal" ) ); // 2018.12.02
+    QWidget * internalView = static_cast<QWidget*>( ktlFindQObjectChild( m_view, "KateViewInternal" ) );
 	
 	connect( m_view, SIGNAL(cursorPositionChanged(KTextEditor::View *, const KTextEditor::Cursor &)),	this, SLOT(slotCursorPositionChanged()) );
 	connect( m_view, SIGNAL(selectionChanged(KTextEditor::View *)), this, SLOT(slotSelectionmChanged()) );
@@ -186,16 +190,16 @@ TextView::TextView( TextDocument * textDocument, ViewContainer *viewContainer, u
     QList< QAction* > actList = m_view->actionCollection()->actions();
     for (QList<QAction*>::iterator itAct = actList.begin(); itAct != actList.end(); ++itAct) {
         KAction *act = static_cast<KAction*>( *itAct );
-        qDebug() << Q_FUNC_INFO << "act: " << act->text() << " acc " << act->accel() << ":" << act ;
+        qDebug() << Q_FUNC_INFO << "act: " << act->text() << " shortcut " << act->shortcut() << ":" << act ;
 
-        if ( (QLatin1String(act->name()) == QLatin1String("file_save"))
-            || (QLatin1String(act->name()) == QLatin1String("file_save_as"))
-            || (QLatin1String(act->name()) == QLatin1String("file_print"))
-            || (QLatin1String(act->name()) == QLatin1String("edit_undo"))
-            || (QLatin1String(act->name()) == QLatin1String("edit_redo"))
-            || (QLatin1String(act->name()) == QLatin1String("edit_cut"))
-            || (QLatin1String(act->name()) == QLatin1String("edit_copy"))
-            || (QLatin1String(act->name()) == QLatin1String("edit_paste"))
+        if ( ((act->objectName()) == QLatin1String("file_save"))
+            || ((act->objectName()) == QLatin1String("file_save_as"))
+            || ((act->objectName()) == QLatin1String("file_print"))
+            || ((act->objectName()) == QLatin1String("edit_undo"))
+            || ((act->objectName()) == QLatin1String("edit_redo"))
+            || ((act->objectName()) == QLatin1String("edit_cut"))
+            || ((act->objectName()) == QLatin1String("edit_copy"))
+            || ((act->objectName()) == QLatin1String("edit_paste"))
         ) {
             act->setShortcutContext(Qt::WidgetWithChildrenShortcut);
             act->setShortcutConfigurable(true);
@@ -291,9 +295,21 @@ void TextView::disableActions()
 {
 	QMenu * tb = (dynamic_cast<KToolBarPopupAction*>(actionByName("program_convert")))->menu();
 	
-	tb->setItemEnabled( TextDocument::AssemblyOutput, false );
-	tb->setItemEnabled( TextDocument::HexOutput, false );
-	tb->setItemEnabled( TextDocument::PICOutput, false );
+    QList<QAction*> actions = tb->actions();
+    Q_FOREACH(QAction *a, actions) {
+        switch (a->data().toInt()) {
+            case TextDocument::AssemblyOutput:
+            case TextDocument::HexOutput:
+            case TextDocument::PICOutput:
+                a->setEnabled( false );
+                break;
+            default:
+                qDebug() << Q_FUNC_INFO << " skip action: " << a;
+        }
+    }
+	//tb->setItemEnabled( TextDocument::AssemblyOutput, false );    // 2018.12.02
+	//tb->setItemEnabled( TextDocument::HexOutput, false );
+	//tb->setItemEnabled( TextDocument::PICOutput, false );
 	actionByName("format_asm")->setEnabled(false);
 	
 #ifndef NO_GPSIM
@@ -345,12 +361,28 @@ void TextView::initCodeActions()
 	
 	QMenu * tb = (dynamic_cast<KToolBarPopupAction*>(actionByName("program_convert")))->menu();
 	
+    QAction *actHexOut = NULL;
+    QAction *actPicOut = NULL;
+    QAction *actAsmOut = NULL;
+    QList<QAction*> actions = tb->actions();
+    Q_FOREACH(QAction *a, actions) {
+        switch (a->data().toInt()) {
+            case TextDocument::AssemblyOutput:  actAsmOut = a; break;
+            case TextDocument::HexOutput:       actHexOut = a; break;
+            case TextDocument::PICOutput:       actPicOut = a; break;
+            default:
+                qDebug() << Q_FUNC_INFO << " skip action: " << a;
+        }
+    }
+
 	switch ( textDocument()->guessedCodeType() )
 	{
 		case TextDocument::ct_asm:
 		{
-			tb->setItemEnabled( TextDocument::HexOutput, true );
-			tb->setItemEnabled( TextDocument::PICOutput, true );
+			//tb->setItemEnabled( TextDocument::HexOutput, true );  // 2018.12.02
+			//tb->setItemEnabled( TextDocument::PICOutput, true );
+            actHexOut->setEnabled( true );
+            actPicOut->setEnabled( true );
 			actionByName("format_asm")->setEnabled(true);
 #ifndef NO_GPSIM
 			actionByName("debug_toggle_breakpoint")->setEnabled(true);
@@ -360,22 +392,30 @@ void TextView::initCodeActions()
 		}
 		case TextDocument::ct_c:
 		{
-			tb->setItemEnabled( TextDocument::AssemblyOutput, true );
-			tb->setItemEnabled( TextDocument::HexOutput, true );
-			tb->setItemEnabled( TextDocument::PICOutput, true );
+			//tb->setItemEnabled( TextDocument::AssemblyOutput, true );
+			//tb->setItemEnabled( TextDocument::HexOutput, true );
+			//tb->setItemEnabled( TextDocument::PICOutput, true );
+            actAsmOut->setEnabled( true );
+            actHexOut->setEnabled( true );
+            actPicOut->setEnabled( true );
 			break;
 		}
 		case TextDocument::ct_hex:
 		{
-			tb->setItemEnabled( TextDocument::AssemblyOutput, true );
-			tb->setItemEnabled( TextDocument::PICOutput, true );
+			//tb->setItemEnabled( TextDocument::AssemblyOutput, true );
+			//tb->setItemEnabled( TextDocument::PICOutput, true );
+            actAsmOut->setEnabled( true );
+            actPicOut->setEnabled( true );
 			break;
 		}
 		case TextDocument::ct_microbe:
 		{
-			tb->setItemEnabled( TextDocument::AssemblyOutput, true );
-			tb->setItemEnabled( TextDocument::HexOutput, true );
-			tb->setItemEnabled( TextDocument::PICOutput, true );
+			//tb->setItemEnabled( TextDocument::AssemblyOutput, true );
+			//tb->setItemEnabled( TextDocument::HexOutput, true );
+			//tb->setItemEnabled( TextDocument::PICOutput, true );
+            actAsmOut->setEnabled( true );
+            actHexOut->setEnabled( true );
+            actPicOut->setEnabled( true );
 			break;
 		}
 		case TextDocument::ct_unknown:
@@ -633,16 +673,19 @@ void TextViewEventFilter::updateHovering( const QString & currentWord, int line,
 			m_hoverStatus = Hidden;
 		
 		emit wordUnhovered();
-		if ( !m_pSleepTimer->isActive() )
-			m_pSleepTimer->start( 2000, true );
-		
+		if ( !m_pSleepTimer->isActive() ) {
+            m_pSleepTimer->setSingleShot( true );
+			m_pSleepTimer->start( 2000 /*, true */ );
+        }
 		return;
 	}
 	
-	if ( m_hoverStatus != Sleeping )
+	if ( m_hoverStatus != Sleeping ) {
 		emit wordHoveredOver( currentWord, line, col );
-	else
-		m_pHoverTimer->start( 700, true );
+    } else {
+        m_pHoverTimer->setSingleShot( true );
+		m_pHoverTimer->start( 700 /*, true */ );
+    }
 }
 
 
